<?php
if ( ! defined( 'ABSPATH' ) ) { exit; } // Exit if accessed directly


// Add custom style in theme settings
function rivax_theme_settings_style () {
	wp_enqueue_style('rivax_settings_style', RIVAX_THEME_URI . '/admin/assets/css/settings.css', array(), null);
}
add_action( 'redux/page/rivax_kalisa_options/enqueue', 'rivax_theme_settings_style' );




add_action('after_setup_theme', 'rivax_redux_config' );
function rivax_redux_config() {

    if ( ! class_exists( 'Redux' ) ) {
        return;
    }

    $theme = wp_get_theme(); // For use with some settings. Not necessary.
    $theme = $theme->parent() ?: $theme;

    // This is your option name where all the Redux data is stored.
    $opt_name = "rivax_kalisa_options";

    /**
     * ---> SET ARGUMENTS
     * All the possible arguments for Redux.
     * */
    $args = array(
        // TYPICAL -> Change these values as you need/desire
        'opt_name'             => $opt_name,
        // This is where your data is stored in the database and also becomes your global variable name.
        'display_name'         => $theme->get( 'Name' ),
        // Name that appears at the top of your panel
        'display_version'      => $theme->get( 'Version' ),
        // Version that appears at the top of your panel
        'menu_type'            => 'submenu',
        //Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
        'allow_sub_menu'       => true,
        // Show the sections below the admin menu item or not
        'menu_title'           => esc_html__('Theme Settings', 'kalisa'),
        'page_title'           => esc_html__('Theme Settings', 'kalisa'),
        // You will need to generate a Google API key to use this feature.
        // Please visit: https://developers.google.com/fonts/docs/developer_api#Auth
        'google_api_key'       => '',
        // Set it you want google fonts to update weekly. A google_api_key value is required.
        'google_update_weekly' => false,
        // Must be defined to add google fonts to the typography module
        'async_typography'     => false,
        // Use a asynchronous font on the front end or font string
        //'disable_google_fonts_link' => true,                    // Disable this in case you want to create your own google fonts loader
        'admin_bar'            => false,
        // Show the panel pages on the admin bar
        'admin_bar_icon'       => 'dashicons-hammer',
        // Choose an icon for the admin bar menu
        'admin_bar_priority'   => 50,
        // Choose an priority for the admin bar menu
        'global_variable'      => '',
        // Set a different name for your global variable other than the opt_name
        'dev_mode'             => false,
        // Show the time the page took to load, etc
        'update_notice'        => false,
        // If dev_mode is enabled, will notify developer of updated versions available in the GitHub Repo
        'customizer'           => false,
        // Enable basic customizer support
        //'open_expanded'     => true,                    // Allow you to start the panel in an expanded way initially.
        //'disable_save_warn' => true,                    // Disable the save warning when a user changes a field

        // OPTIONAL -> Give you extra features
        'page_priority'        => 72,
        // Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
        'page_parent'          => 'rivax-dashboard',
        // For a full list of options, visit: http://codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
        'page_permissions'     => 'manage_options',
        // Permissions needed to access the options panel.
        'menu_icon'            => '',
        // Specify a custom URL to an icon
        'last_tab'             => '',
        // Force your panel to always open to a specific tab (by id)
        'page_icon'            => 'icon-themes',
        // Icon displayed in the admin panel next to your menu_title
        'page_slug'            => 'rivax-settings',
        // Page slug used to denote the panel, will be based off page title then menu title then opt_name if not provided
        'save_defaults'        => true,
        // On load save the defaults to DB before user clicks save or not
        'default_show'         => false,
        // If true, shows the default value next to each field that is not the default value.
        'default_mark'         => '',
        // What to print by the field's title if the value shown is default. Suggested: *
        'show_import_export'   => true,
        // Shows the Import/Export panel when not used as a field.

        // CAREFUL -> These options are for advanced use only
        'transient_time'       => 60 * MINUTE_IN_SECONDS,
        'output'               => true,
        // Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
        'output_tag'           => true,
        // Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
        'output_location'                  => array( 'frontend', 'admin' ),
	    // Admin area: Enqueue dynamic CSS and Google fonts.
        // 'footer_credit'     => '',                   // Disable the footer credit of Redux. Please leave if you can help it.

        // FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
        'database'             => '',
        // possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!
        'use_cdn'              => true
        // If you prefer not to use the CDN for Select2, Ace Editor, and others, you may download the Redux Vendor Support plugin yourself and run locally or embed it in your code.

    );

// Add content after the form.
    $args['footer_text'] = '<p>' . esc_html__('Designed by: ', 'kalisa') . '<a href="https://themeforest.net/user/rivaxstudio/" target="_blank">Rivax Studio</a>.</p>';

    Redux::set_args( $opt_name, $args );

    /*
 * ---> END ARGUMENTS
 */

 /*
 *
 * ---> START SECTIONS
 *
 */

    Redux::set_section( $opt_name, array(
        'title'            =>  esc_html__('General', 'kalisa'),
        'id'               => 'general_section',
        'desc'             =>  esc_html__('General settings for site', 'kalisa'),
        'icon'             => 'el el-cog',
        'fields'           => array(
			array(
                'id'       => 'site-width',
                'type'     => 'slider',
                'title'    => esc_html__('Site Width', 'kalisa'),
                'subtitle' => esc_html__('Choose the site width.', 'kalisa'),
                'desc'     => esc_html__('Default: 1300.', 'kalisa'),
                'default'  => 1300,
                'min'       => 1200,
                'step'      => 10,
                'max'       => 1800,
            ),
            array(
                'id'       => 'sticky-sidebar',
                'type'     => 'switch',
                'on'     => esc_html__('Enable', 'kalisa'),
                'off'     => esc_html__('Disable', 'kalisa'),
                'title'    => esc_html__('Sticky Sidebar', 'kalisa'),
                'subtitle' => esc_html__('Make sidebar sticky.', 'kalisa'),
                'desc'     => '',
                'default'  => true,
            ),

            array(
                'id'       => 'site-preloader',
                'type'     => 'switch',
                'on'     => esc_html__('Enable', 'kalisa'),
                'off'     => esc_html__('Disable', 'kalisa'),
                'title'    => esc_html__('Preloader', 'kalisa'),
                'subtitle' => esc_html__('Show site preloader transition before site loaded.', 'kalisa'),
                'desc'     => '',
                'default'  => false,
            ),

            array(
                'id'       => 'smooth-scroll',
                'type'     => 'switch',
                'on'     => esc_html__('Enable', 'kalisa'),
                'off'     => esc_html__('Disable', 'kalisa'),
                'title'    => esc_html__('Smooth Scroll', 'kalisa'),
                'subtitle' => esc_html__('Smooth scroll in website.', 'kalisa'),
                'desc'     => '',
                'default'  => false,
            ),

            array(
                'id'       => 'full-size-gif',
                'type'     => 'switch',
                'on'     => esc_html__('Enable', 'kalisa'),
                'off'     => esc_html__('Disable', 'kalisa'),
                'title'    => esc_html__('Full Size Gif Images', 'kalisa'),
                'subtitle' => esc_html__('Use full image size for Gif. It is useful to show gif animation in thumbnail.', 'kalisa'),
                'desc'     => '',
                'default'  => true,
            ),

        )
    ) );

    Redux::set_section( $opt_name, array(
        'title'            =>  esc_html__('Header', 'kalisa'),
        'id'               => 'header_section',
        'desc'             =>  esc_html__('General settings for header', 'kalisa'),
        'icon'             => 'el el-website',
        'fields'           => array(

            array(
                'id'       => 'site-header',
                'type'     => 'select',
                'title'    => esc_html__('Site Header Template', 'kalisa'),
                'subtitle' => esc_html__('Select header template for your site.', 'kalisa'),
                'data'  => 'callback',
                'args' => 'rivax_get_templates_list',
                'desc'     => sprintf(esc_html__('You can create your custom template in %1$s Rivax Templates %2$s section.', 'kalisa'), '<a target="_blank" href="' . admin_url("edit.php?post_type=rivax-template") . '"><b>', '</b></a>'),
                'default' => '0',
                'select2'  => array( 'allowClear' => false ),
            ),

            array(
                'id'       => 'single-post-header',
                'type'     => 'select',
                'title'    => esc_html__('Single Post Header Template', 'kalisa'),
                'subtitle' => esc_html__('Select header template for the single post.', 'kalisa'),
                'data'  => 'callback',
                'args' => 'rivax_get_templates_list',
                'desc'     => sprintf(esc_html__('Default inherit from site header template. You can create your custom template in %1$s Rivax Templates %2$s section.', 'kalisa'), '<a target="_blank" href="' . admin_url("edit.php?post_type=rivax-template") . '"><b>', '</b></a>'),
                'default' => '0',
                'select2'  => array( 'allowClear' => false ),
            ),

            array(
                'id'       => 'single-post-float-header',
                'type'     => 'switch',
                'on'     => esc_html__('Enable', 'kalisa'),
                'off'     => esc_html__('Disable', 'kalisa'),
                'title'    => esc_html__('Single Post Float Header', 'kalisa'),
                'subtitle' => esc_html__('Make header float in single post.', 'kalisa'),
                'desc'     => '',
                'default'  => false,
            ),

            array(
                'id'       => 'float-header-glass-bg-blur',
                'type'     => 'slider',
                'title'    => esc_html__('Float Header Glassmorphism', 'kalisa'),
                'subtitle' => esc_html__('Make float header glassmorphism. Set background color opacity lower than 1 for header. Currently, this feature does not work in Firefox.', 'kalisa'),
                'desc'     => '',
                'default'  => '',
                'min'       => 0,
                'step'      => 1,
                'max'       => 30,
            ),

            array(
                'id'       => 'sticky-header-status',
                'type'     => 'switch',
                'on'     => esc_html__('Enable', 'kalisa'),
                'off'     => esc_html__('Disable', 'kalisa'),
                'title'    => esc_html__('Sticky Header', 'kalisa'),
                'subtitle' => esc_html__('Enable sticky header for your site.', 'kalisa'),
                'desc'     => '',
                'default'  => false,
            ),

            array(
                'id'       => 'site-sticky-header',
                'type'     => 'select',
                'required' => array( 'sticky-header-status', '=', '1' ),
                'title'    => esc_html__('Site Sticky Header', 'kalisa'),
                'subtitle' => esc_html__('Select sticky header for the site.', 'kalisa'),
                'data'  => 'callback',
                'args' => 'rivax_get_templates_list',
                'desc'     => sprintf(esc_html__('You can create your custom template in %1$s Rivax Templates %2$s section.', 'kalisa'), '<a target="_blank" href="' . admin_url("edit.php?post_type=rivax-template") . '"><b>', '</b></a>'),
                'default' => '0',
                'select2'  => array( 'allowClear' => false ),
            ),

	        array(
		        'id'       => 'single-post-sticky-header',
		        'type'     => 'select',
		        'required' => array( 'sticky-header-status', '=', '1' ),
		        'title'    => esc_html__('Single Post Sticky Header Template', 'kalisa'),
		        'subtitle' => esc_html__('Select sticky header template for the single post.', 'kalisa'),
		        'data'  => 'callback',
		        'args' => 'rivax_get_templates_list',
		        'desc'     => sprintf(esc_html__('Default inherit from site sticky header template. You can create your custom template in %1$s Rivax Templates %2$s section.', 'kalisa'), '<a target="_blank" href="' . admin_url("edit.php?post_type=rivax-template") . '"><b>', '</b></a>'),
		        'default' => '0',
		        'select2'  => array( 'allowClear' => false ),
	        ),

            array(
                'id'       => 'sticky-header-glass-bg-blur',
                'type'     => 'slider',
                'required' => array( 'sticky-header-status', '=', '1' ),
                'title'    => esc_html__('Sticky Header Glassmorphism', 'kalisa'),
                'subtitle' => esc_html__('Make sticky header glassmorphism. Set background color opacity lower than 1 for sticky header. Currently, this feature does not work in Firefox.', 'kalisa'),
                'desc'     => '',
                'default'  => '',
                'min'       => 0,
                'step'      => 1,
                'max'       => 30,
            ),

        )
    ) );

    Redux::set_section( $opt_name, array(
        'title'            =>  esc_html__('Footer', 'kalisa'),
        'id'               => 'footer_section',
        'desc'             =>  esc_html__('General settings for footer', 'kalisa'),
        'icon'             => 'el el-credit-card',
        'fields'           => array(
            array(
                'id'       => 'site-footer',
                'type'     => 'select',
                'title'    => esc_html__('Site Footer', 'kalisa'),
                'subtitle' => esc_html__('Select footer for the site.', 'kalisa'),
                'data'  => 'callback',
                'args' => 'rivax_get_templates_list',
                'desc'     => sprintf(esc_html__('You can create your custom template in %1$s Rivax Templates %2$s section.', 'kalisa'), '<a target="_blank" href="' . admin_url("edit.php?post_type=rivax-template") . '"><b>', '</b></a>'),
                'default' => '0',
                'select2'  => array( 'allowClear' => false ),
            ),
            array(
                'id'       => 'back-to-top',
                'type'     => 'switch',
                'on'     => esc_html__('Enable', 'kalisa'),
                'off'     => esc_html__('Disable', 'kalisa'),
                'title'    => esc_html__('Back to Top Button', 'kalisa'),
                'subtitle' => esc_html__('Enable or disable back to top button.', 'kalisa'),
                'desc'     => '',
                'default'  => false,
            ),

            array(
                'id'       => 'back-to-top-bg',
                'type'     => 'color',
                'transparent'     => false,
                'title'    => esc_html__('Back to Top Button Background', 'kalisa'),
                'subtitle' => '',
                'desc'     => '',
                'default'  => '',
                'validate' => 'color',
            ),

            array(
                'id'       => 'footer-canvas-menu-bg',
                'type'     => 'color',
                'transparent'     => false,
                'title'    => esc_html__('Footer Canvas Menu Background', 'kalisa'),
                'subtitle' => '',
                'desc'     => '',
                'default'  => '',
                'validate' => 'color',
            ),
            array(
                'id'       => 'footer-canvas-menu-color',
                'type'     => 'color',
                'transparent'     => false,
                'title'    => esc_html__('Footer Canvas Menu Link Color', 'kalisa'),
                'subtitle' => '',
                'desc'     => '',
                'default'  => '',
                'validate' => 'color',
            ),
            array(
                'id'       => 'footer-canvas-menu-color-hover',
                'type'     => 'color',
                'transparent'     => false,
                'title'    => esc_html__('Footer Canvas Menu Link Hover Color', 'kalisa'),
                'subtitle' => '',
                'desc'     => '',
                'default'  => '',
                'validate' => 'color',
            ),
        )
    ) );


    Redux::set_section( $opt_name, array(
        'title'            =>  esc_html__('Sidebar', 'kalisa'),
        'id'               => 'sidebar_section',
        'desc'             =>  esc_html__('General settings for sidebar', 'kalisa'),
        'icon'             => 'el el-align-left',
        'fields'           => array(
            array(
                'id'       => 'subtitle-756694',
                'type'     => 'raw',
                'full_width'     => true,
                'content'     => '<h4>' . esc_html__('Single Page Sidebar', 'kalisa') . '</h4>',
            ),
            array(
                'id'       => 'single-page-sidebar-position',
                'type'     => 'select',
                'title'    => esc_html__('Single Page Sidebar Position', 'kalisa'),
                'subtitle' => esc_html__('Select sidebar position for pages.', 'kalisa'),
                'desc'     => '',
                'options'  => array(
                    'left' => esc_html__('Left', 'kalisa'),
                    'right' => esc_html__('Right', 'kalisa'),
                    'none' => esc_html__('No Sidebar', 'kalisa'),
                    'none-narrow' => esc_html__('No Sidebar + Narrow Content', 'kalisa'),
                ),
                'select2'  => array( 'allowClear' => false ),
                'default'  => 'none',
            ),
            array(
                'id'       => 'single-page-sidebar-template',
                'type'     => 'select',
                'title'    => esc_html__('Single Page Sidebar Template', 'kalisa'),
                'subtitle' => esc_html__('Select template for this sidebar.', 'kalisa'),
                'data'  => 'callback',
                'args' => 'rivax_get_templates_list',
                'desc'     => sprintf(esc_html__('You can create your custom template in %1$s Rivax Templates %2$s section.', 'kalisa'), '<a target="_blank" href="' . admin_url("edit.php?post_type=rivax-template") . '"><b>', '</b></a>'),
                'default' => '0',
                'select2'  => array( 'allowClear' => false ),
            ),

            array(
                'id'       => 'subtitle-355494',
                'type'     => 'raw',
                'full_width'     => true,
                'content'     => '<h4>' . esc_html__('Single Post Sidebar', 'kalisa') . '</h4>',
            ),
            array(
                'id'       => 'single-post-sidebar-position',
                'type'     => 'select',
                'title'    => esc_html__('Single Post Sidebar Position', 'kalisa'),
                'subtitle' => esc_html__('Select sidebar position for single post.', 'kalisa'),
                'desc'     => '',
                'options'  => array(
                    'left' => esc_html__('Left', 'kalisa'),
                    'right' => esc_html__('Right', 'kalisa'),
                    'none' => esc_html__('No Sidebar', 'kalisa'),
                    'none-narrow' => esc_html__('No Sidebar + Narrow Content', 'kalisa'),
                ),
                'select2'  => array( 'allowClear' => false ),
                'default'  => 'none',
            ),
            array(
                'id'       => 'single-post-sidebar-template',
                'type'     => 'select',
                'title'    => esc_html__('Single Post Sidebar Template', 'kalisa'),
                'subtitle' => esc_html__('Select template for this sidebar.', 'kalisa'),
                'data'  => 'callback',
                'args' => 'rivax_get_templates_list',
                'desc'     => sprintf(esc_html__('You can create your custom template in %1$s Rivax Templates %2$s section.', 'kalisa'), '<a target="_blank" href="' . admin_url("edit.php?post_type=rivax-template") . '"><b>', '</b></a>'),
                'default' => '0',
                'select2'  => array( 'allowClear' => false ),
            ),

            array(
                'id'       => 'subtitle-755494',
                'type'     => 'raw',
                'full_width'     => true,
                'content'     => '<h4>' . esc_html__('Blog Sidebar', 'kalisa') . '</h4>',
            ),
            array(
                'id'       => 'blog-sidebar-position',
                'type'     => 'select',
                'title'    => esc_html__('Blog Sidebar Position', 'kalisa'),
                'subtitle' => esc_html__('Select sidebar position for blog archive.', 'kalisa'),
                'desc'     => '',
                'options'  => array(
                    'left' => esc_html__('Left', 'kalisa'),
                    'right' => esc_html__('Right', 'kalisa'),
                    'none' => esc_html__('No Sidebar', 'kalisa'),
                ),
                'select2'  => array( 'allowClear' => false ),
                'default'  => 'none',
            ),
            array(
                'id'       => 'blog-sidebar-template',
                'type'     => 'select',
                'title'    => esc_html__('Blog Sidebar Template', 'kalisa'),
                'subtitle' => esc_html__('Select template for this sidebar.', 'kalisa'),
                'data'  => 'callback',
                'args' => 'rivax_get_templates_list',
                'desc'     => sprintf(esc_html__('You can create your custom template in %1$s Rivax Templates %2$s section.', 'kalisa'), '<a target="_blank" href="' . admin_url("edit.php?post_type=rivax-template") . '"><b>', '</b></a>'),
                'default' => '0',
                'select2'  => array( 'allowClear' => false ),
            ),

            array(
                'id'       => 'subtitle-756794',
                'type'     => 'raw',
                'full_width'     => true,
                'content'     => '<h4>' . esc_html__('Woocommerce Sidebar', 'kalisa') . '</h4>',
            ),
            array(
                'id'       => 'woocommerce-shop-sidebar-position',
                'type'     => 'select',
                'title'    => esc_html__('Woocommerce Shop Sidebar Position', 'kalisa'),
                'subtitle' => esc_html__('Select sidebar position for woocommerce shop.', 'kalisa'),
                'desc'     => '',
                'options'  => array(
                    'left' => esc_html__('Left', 'kalisa'),
                    'right' => esc_html__('Right', 'kalisa'),
                    'none' => esc_html__('No Sidebar', 'kalisa'),
                ),
                'select2'  => array( 'allowClear' => false ),
                'default'  => 'none',
            ),
	        array(
		        'id'       => 'woocommerce-archive-sidebar-position',
		        'type'     => 'select',
		        'title'    => esc_html__('Woocommerce Archive Sidebar Position', 'kalisa'),
		        'subtitle' => esc_html__('Select sidebar position for woocommerce archive.', 'kalisa'),
		        'desc'     => '',
		        'options'  => array(
			        'left' => esc_html__('Left', 'kalisa'),
			        'right' => esc_html__('Right', 'kalisa'),
			        'none' => esc_html__('No Sidebar', 'kalisa'),
		        ),
		        'select2'  => array( 'allowClear' => false ),
		        'default'  => 'none',
	        ),
            array(
                'id'       => 'woocommerce-sidebar-template',
                'type'     => 'select',
                'title'    => esc_html__('Woocommerce Sidebar Template', 'kalisa'),
                'subtitle' => esc_html__('Select template for this sidebar.', 'kalisa'),
                'data'  => 'callback',
                'args' => 'rivax_get_templates_list',
                'desc'     => sprintf(esc_html__('You can create your custom template in %1$s Rivax Templates %2$s section.', 'kalisa'), '<a target="_blank" href="' . admin_url("edit.php?post_type=rivax-template") . '"><b>', '</b></a>'),
                'default' => '0',
                'select2'  => array( 'allowClear' => false ),
            ),

        )
    ) );



    Redux::set_section( $opt_name, array(
        'title'            =>  esc_html__('Styling', 'kalisa'),
        'id'               => 'styling_section',
        'desc'             =>  esc_html__('Styling settings', 'kalisa'),
        'icon'             => 'el el-brush',
        'fields'           => array(
            array(
                'id'       => 'accent-color',
                'type'     => 'color',
                'transparent'     => false,
                'title'    => esc_html__('Accent Color', 'kalisa'),
                'subtitle' => '',
                'desc'     => '',
                'default'  => '',
                'validate' => 'color',
            ),
            array(
                'id'       => 'second-color',
                'type'     => 'color',
                'transparent'     => false,
                'title'    => esc_html__('Second Color', 'kalisa'),
                'subtitle' => '',
                'desc'     => '',
                'default'  => '',
                'validate' => 'color',
            ),
            array(
                'id'       => 'body-bg',
                'type'     => 'color',
                'transparent'     => false,
                'title'    => esc_html__('Body Background Color', 'kalisa'),
                'subtitle' => '',
                'desc'     => '',
                'default'  => '',
                'validate' => 'color',
            ),
            array(
                'id'       => 'body-color',
                'type'     => 'color',
                'transparent'     => false,
                'title'    => esc_html__('Body Text Color', 'kalisa'),
                'subtitle' => '',
                'desc'     => '',
                'default'  => '',
                'validate' => 'color',
            ),
            array(
                'id'       => 'heading-color',
                'type'     => 'color',
                'transparent'     => false,
                'title'    => esc_html__('Headings Color', 'kalisa'),
                'subtitle' => '',
                'desc'     => '',
                'default'  => '',
                'validate' => 'color',
            ),
            array(
                'id'       => 'single-progress-bar-bg',
                'type'     => 'color_gradient',
                'transparent'     => false,
                'title'    => esc_html__('Single Post Progress Bar Color', 'kalisa'),
                'subtitle' => '',
                'desc'     => '',
                'default'        => array(
                    'from'           => '',
                    'to'             => '',
                ),
                'validate' => 'color',
            ),
            array(
                'id'       => 'single-category-bg',
                'type'     => 'color',
                'transparent'     => false,
                'title'    => esc_html__('Single Post Category Background', 'kalisa'),
                'subtitle' => '',
                'desc'     => '',
                'default'  => '',
                'validate' => 'color',
            ),
            array(
                'id'       => 'single-category-bg-hover',
                'type'     => 'color',
                'transparent'     => false,
                'title'    => esc_html__('Single Post Category Background Hover', 'kalisa'),
                'subtitle' => '',
                'desc'     => '',
                'default'  => '',
                'validate' => 'color',
            ),
            array(
                'id'       => 'button-bg-hover',
                'type'     => 'color',
                'transparent'     => false,
                'title'    => esc_html__('Button Background Hover', 'kalisa'),
                'subtitle' => '',
                'desc'     => '',
                'default'  => '',
                'validate' => 'color',
            ),
            array(
                'id'       => 'single-highlight-bg',
                'type'     => 'color',
                'transparent'     => false,
                'title'    => esc_html__('Single Post Highlight Background', 'kalisa'),
                'subtitle' => esc_html__('Single hero style 3, 8, 9, 12, 13, 14', 'kalisa'),
                'desc'     => '',
                'default'  => '',
                'validate' => 'color',
            ),
            array(
                'id'       => 'single-highlight-color',
                'type'     => 'color',
                'transparent'     => false,
                'title'    => esc_html__('Single Post Highlight Color', 'kalisa'),
                'subtitle' => esc_html__('Single hero style 3, 8, 9, 12, 13, 14', 'kalisa'),
                'desc'     => '',
                'default'  => '',
                'validate' => 'color',
            ),



        )
    ) );


    Redux::set_section( $opt_name, array(
        'title'            => esc_html__('Typography', 'kalisa'),
        'id'               => 'typography',
        'desc'             => esc_html__('Typography settings', 'kalisa'),
        'subsection'       => false,
        'icon'             => 'el el-fontsize',
        'fields'           => array(
            array(
                'id'       => 'typography-body',
                'type'     => 'typography',
				'all_styles'      => true,
                'google'      => true,
                'color'      => false,
                'text-align'      => false,
                'subsets'      => false,
                'line-height'      => false,
                'units'       =>'px',
                'title'    => esc_html__('Body Typography', 'kalisa'),
            ),
            array(
                'id'       => 'typography-heading',
                'type'     => 'typography',
                'google'      => true,
                'color'      => false,
                'text-align'      => false,
                'subsets'      => false,
                'line-height'      => false,
                'font-size'      => false,
                'title'    => esc_html__('Headings Typography', 'kalisa'),
            ),
            array(
                'id'       => 'typography-heading-h1',
                'type'     => 'typography',
                'google'      => true,
                'color'      => false,
                'text-align'      => false,
                'subsets'      => false,
                'line-height'      => false,
                'font-size'      => false,
                'title'    => esc_html__('Heading H1 Typography', 'kalisa'),
            ),
            array(
                'id'       => 'typography-heading-h2',
                'type'     => 'typography',
                'google'      => true,
                'color'      => false,
                'text-align'      => false,
                'subsets'      => false,
                'line-height'      => false,
                'font-size'      => false,
                'title'    => esc_html__('Heading H2 Typography', 'kalisa'),
            ),
            array(
                'id'       => 'typography-heading-h3',
                'type'     => 'typography',
                'google'      => true,
                'color'      => false,
                'text-align'      => false,
                'subsets'      => false,
                'line-height'      => false,
                'font-size'      => false,
                'title'    => esc_html__('Heading H3 Typography', 'kalisa'),
            ),
            array(
                'id'       => 'typography-heading-h4',
                'type'     => 'typography',
                'google'      => true,
                'color'      => false,
                'text-align'      => false,
                'subsets'      => false,
                'line-height'      => false,
                'font-size'      => false,
                'title'    => esc_html__('Heading H4 Typography', 'kalisa'),
            ),
            array(
                'id'       => 'typography-heading-h5',
                'type'     => 'typography',
                'google'      => true,
                'color'      => false,
                'text-align'      => false,
                'subsets'      => false,
                'line-height'      => false,
                'font-size'      => false,
                'title'    => esc_html__('Heading H5 Typography', 'kalisa'),
            ),
            array(
                'id'       => 'typography-heading-h6',
                'type'     => 'typography',
                'google'      => true,
                'color'      => false,
                'text-align'      => false,
                'subsets'      => false,
                'line-height'      => false,
                'font-size'      => false,
                'title'    => esc_html__('Heading H6 Typography', 'kalisa'),
            ),
	        array(
		        'id'       => 'typography-terms',
		        'type'     => 'typography',
		        'google'      => true,
		        'color'      => false,
		        'text-align'      => false,
		        'subsets'      => false,
		        'line-height'      => false,
		        'font-size'      => false,
		        'title'    => esc_html__('Terms Typography', 'kalisa'),
	        ),
            array(
                'id'       => 'title-font-size-9856',
                'type'     => 'raw',
                'full_width'     => true,
                'content'     => '<h2>' . esc_html__('Font Size', 'kalisa') . '</h2>',
            ),
            array(
                'id'       => 'h1-font-size',
                'type'     => 'text',
                'title'    => esc_html__('H1 Font Size', 'kalisa'),
                'subtitle' => esc_html__('Enter H1 font size. Example: 28px or 1.8rem', 'kalisa'),
            ),
            array(
                'id'       => 'h2-font-size',
                'type'     => 'text',
                'title'    => esc_html__('H2 Font Size', 'kalisa'),
                'subtitle' => esc_html__('Enter H2 font size. Example: 28px or 1.8rem', 'kalisa'),
            ),
            array(
                'id'       => 'h3-font-size',
                'type'     => 'text',
                'title'    => esc_html__('H3 Font Size', 'kalisa'),
                'subtitle' => esc_html__('Enter H3 font size. Example: 28px or 1.8rem', 'kalisa'),
            ),
            array(
                'id'       => 'h4-font-size',
                'type'     => 'text',
                'title'    => esc_html__('H4 Font Size', 'kalisa'),
                'subtitle' => esc_html__('Enter H4 font size. Example: 28px or 1.8rem', 'kalisa'),
            ),
            array(
                'id'       => 'h5-font-size',
                'type'     => 'text',
                'title'    => esc_html__('H5 Font Size', 'kalisa'),
                'subtitle' => esc_html__('Enter H5 font size. Example: 28px or 1.8rem', 'kalisa'),
            ),
            array(
                'id'       => 'h6-font-size',
                'type'     => 'text',
                'title'    => esc_html__('H6 Font Size', 'kalisa'),
                'subtitle' => esc_html__('Enter H6 font size. Example: 28px or 1.8rem', 'kalisa'),
            ),

            array(
                'id'       => 'title-font-size-984556',
                'type'     => 'raw',
                'full_width'     => true,
                'content'     => '<h2>' . esc_html__('Font Size In Responsive', 'kalisa') . '</h2>',
            ),
            array(
                'id'       => 'h1-font-size-responsive',
                'type'     => 'text',
                'title'    => esc_html__('H1 Font Size In Mobile And Tablet', 'kalisa'),
                'subtitle' => esc_html__('Enter H1 font size. Example: 28px or 1.8rem', 'kalisa'),
            ),
            array(
                'id'       => 'h2-font-size-responsive',
                'type'     => 'text',
                'title'    => esc_html__('H2 Font Size In Mobile And Tablet', 'kalisa'),
                'subtitle' => esc_html__('Enter H2 font size. Example: 28px or 1.8rem', 'kalisa'),
            ),
            array(
                'id'       => 'h3-font-size-responsive',
                'type'     => 'text',
                'title'    => esc_html__('H3 Font Size In Mobile And Tablet', 'kalisa'),
                'subtitle' => esc_html__('Enter H3 font size. Example: 28px or 1.8rem', 'kalisa'),
            ),
            array(
                'id'       => 'h4-font-size-responsive',
                'type'     => 'text',
                'title'    => esc_html__('H4 Font Size In Mobile And Tablet', 'kalisa'),
                'subtitle' => esc_html__('Enter H4 font size. Example: 28px or 1.8rem', 'kalisa'),
            ),
            array(
                'id'       => 'h5-font-size-responsive',
                'type'     => 'text',
                'title'    => esc_html__('H5 Font Size In Mobile And Tablet', 'kalisa'),
                'subtitle' => esc_html__('Enter H5 font size. Example: 28px or 1.8rem', 'kalisa'),
            ),
            array(
                'id'       => 'h6-font-size-responsive',
                'type'     => 'text',
                'title'    => esc_html__('H6 Font Size In Mobile And Tablet', 'kalisa'),
                'subtitle' => esc_html__('Enter H6 font size. Example: 28px or 1.8rem', 'kalisa'),
            ),


        )
    ) );


    Redux::set_section( $opt_name, array(
        'title'            => esc_html__('Single Post', 'kalisa'),
        'id'               => 'single_post_section',
        'desc'             => esc_html__('Single Post settings', 'kalisa'),
        'subsection'       => false,
        'icon'             => 'el el-pencil',
    ) );


    Redux::set_section( $opt_name, array(
        'title'            => esc_html__('General', 'kalisa'),
        'id'               => 'single_post_general',
        'desc'             => esc_html__('Single Post general settings', 'kalisa'),
        'subsection'       => true,
        'icon'             => 'el el-cog',
        'fields'           => array(

            array(
                'id'       => 'single-post-top-content-template',
                'type'     => 'select',
                'title'    => esc_html__('Top Content', 'kalisa'),
                'subtitle' => esc_html__('Select template to show in top of the post.', 'kalisa'),
                'data'  => 'callback',
                'args' => 'rivax_get_templates_list',
                'desc'     => sprintf(esc_html__('You can create your custom template in %1$s Rivax Templates %2$s section.', 'kalisa'), '<a target="_blank" href="' . admin_url("edit.php?post_type=rivax-template") . '"><b>', '</b></a>'),
                'default' => '0',
                'select2'  => array( 'allowClear' => false ),
            ),
            array(
                'id'       => 'single-post-bottom-content-template',
                'type'     => 'select',
                'title'    => esc_html__('Bottom Content', 'kalisa'),
                'subtitle' => esc_html__('Select template to show in bottom of the post.', 'kalisa'),
                'data'  => 'callback',
                'args' => 'rivax_get_templates_list',
                'desc'     => sprintf(esc_html__('You can create your custom template in %1$s Rivax Templates %2$s section.', 'kalisa'), '<a target="_blank" href="' . admin_url("edit.php?post_type=rivax-template") . '"><b>', '</b></a>'),
                'default' => '0',
                'select2'  => array( 'allowClear' => false ),
            ),
            array(
                'id'       => 'post-reading-progress-indicator',
                'type'     => 'switch',
                'on'     => esc_html__('Enable', 'kalisa'),
                'off'     => esc_html__('Disable', 'kalisa'),
                'title'    => esc_html__('Reading Progress Indicator', 'kalisa'),
                'subtitle' => esc_html__('Show reading progress indicator in post.', 'kalisa'),
                'desc'     => '',
                'default'  => true,
            ),
			array(
                'id'       => 'disable-tags',
                'type'     => 'switch',
                'on'     => esc_html__('Enable', 'kalisa'),
                'off'     => esc_html__('Disable', 'kalisa'),
                'title'    => esc_html__('Disable Tags', 'kalisa'),
                'subtitle' => esc_html__('Disable showing tags from the bottom of posts.', 'kalisa'),
                'desc'     => '',
            ),
            array(
                'id'       => 'comments-list-collapsable',
                'type'     => 'switch',
                'on'     => esc_html__('Enable', 'kalisa'),
                'off'     => esc_html__('Disable', 'kalisa'),
                'title'    => esc_html__('Comments List Collapsable', 'kalisa'),
                'subtitle' => esc_html__('Makes comments list collapsable with show/hide button.', 'kalisa'),
                'desc'     => '',
                'default'  => true,
            ),
            array(
                'id'       => 'single-post-share-box',
                'type'     => 'switch',
                'on'     => esc_html__('Enable', 'kalisa'),
                'off'     => esc_html__('Disable', 'kalisa'),
                'title'    => esc_html__('Show Share Box', 'kalisa'),
                'subtitle' => esc_html__('Show share box in the single post.', 'kalisa'),
                'desc'     => '',
                'default'  => true,
            ),
            array(
                'id'       => 'single-post-share-box-options',
                'type'     => 'checkbox',
                'required' => array( 'single-post-share-box', '=', '1' ),
                'title'    => esc_html__('Share Box Options', 'kalisa'),
                'subtitle' => esc_html__('Select share box options.', 'kalisa'),
                'desc'     => '',
                'options'  => array(
                    'facebook' => esc_html__('Facebook', 'kalisa'),
                    'twitter' => esc_html__('Twitter', 'kalisa'),
                    'linkedin' => esc_html__('Linkedin', 'kalisa'),
                    'pinterest' => esc_html__('Pinterest', 'kalisa'),
                    'telegram' => esc_html__('Telegram', 'kalisa'),
                    'email' => esc_html__('Email', 'kalisa'),
                    'whatsapp' => esc_html__('WhatsApp', 'kalisa'),
                    'link' => esc_html__('Link Box', 'kalisa'),
                ),
                'default' => array(
                    'facebook' => '1',
                    'twitter' => '1',
                    'linkedin' => '0',
                    'pinterest' => '1',
                    'telegram' => '0',
                    'email' => '1',
                    'whatsapp' => '1',
                    'link' => '1',
                )
            ),
            array(
                'id'       => 'single-post-author-box',
                'type'     => 'switch',
                'on'     => esc_html__('Enable', 'kalisa'),
                'off'     => esc_html__('Disable', 'kalisa'),
                'title'    => esc_html__('Show Author Box', 'kalisa'),
                'subtitle' => esc_html__('Show author box in the single post.', 'kalisa'),
                'desc'     => '',
                'default'  => true,
            ),
            array(
                'id'       => 'single-post-next-prev-posts',
                'type'     => 'switch',
                'on'     => esc_html__('Enable', 'kalisa'),
                'off'     => esc_html__('Disable', 'kalisa'),
                'title'    => esc_html__('Show Next and Previous Posts', 'kalisa'),
                'subtitle' => esc_html__('Show next and Previous posts in the single post.', 'kalisa'),
                'desc'     => '',
                'default'  => true,
            ),
            array(
                'id'       => 'single-next-prev-posts-title',
                'type'     => 'text',
                'required' => array( 'single-post-next-prev-posts', '=', '1' ),
                'title'    => esc_html__('Next And Previous Posts Title', 'kalisa'),
                'subtitle' => esc_html__('Enter your title for the next and Previous posts.', 'kalisa'),
                'desc'     => esc_html__('Default value: Other Articles', 'kalisa'),
                'default'  => esc_html__('Other Articles', 'kalisa'),
            ),
            array(
                'id'       => 'single-post-fixed-next-prev-posts',
                'type'     => 'switch',
                'on'     => esc_html__('Enable', 'kalisa'),
                'off'     => esc_html__('Disable', 'kalisa'),
                'title'    => esc_html__('Show Fixed Next And Previous Posts', 'kalisa'),
                'subtitle' => esc_html__('Show fixed next and Previous posts in the single post.', 'kalisa'),
                'desc'     => '',
                'default'  => true,
            ),
            array(
                'id'       => 'reading-time-words-per-minute',
                'type'     => 'slider',
                'title'    => esc_html__('Reading Time Words Per Minute', 'kalisa'),
                'subtitle' => esc_html__('How many words user can read per minute?', 'kalisa'),
                'desc'     => esc_html__('Default value: 255', 'kalisa'),
                'default'  => 255,
                'min'       => 100,
                'step'      => 10,
                'max'       => 500,
            ),


        )
    ) );


    Redux::set_section( $opt_name, array(
        'title'            => esc_html__('Hero Layout', 'kalisa'),
        'id'               => 'single_post_layout',
        'desc'             => esc_html__('Single post hero layout settings', 'kalisa'),
        'subsection'       => true,
        'icon'             => 'el el-picture',
        'fields'           => array(
            array(
                'id'       => 'single-default-post-meta',
                'type'     => 'checkbox',
                'title'    => esc_html__('Default Post Meta', 'kalisa'),
                'subtitle' => esc_html__('Select default meta for single post.', 'kalisa'),
                'desc'     => '',
                'options'  => array(
                    'author-name' => esc_html__('Author Name', 'kalisa'),
                    'author-avatar' => esc_html__('Author Avatar', 'kalisa'),
                    'date' => esc_html__('Date', 'kalisa'),
                    'date-updated' => esc_html__('Updated Date', 'kalisa'),
                    'category' => esc_html__('Category', 'kalisa'),
                    'comments' => esc_html__('Comments', 'kalisa'),
                    'views' => esc_html__('Views', 'kalisa'),
                    'reading-time' => esc_html__('Reading Time', 'kalisa'),
                    'excerpt' => esc_html__('Excerpt', 'kalisa'),
                ),
                'default' => array(
                    'author-name' => '1',
                    'author-avatar' => '1',
                    'date' => '1',
                    'date-updated' => '0',
                    'category' => '1',
                    'comments' => '1',
                    'views' => '1',
                    'reading-time' => '1',
                    'excerpt' => '0',
                )
            ),

            array(
                'id'       => 'title-8145',
                'type'     => 'raw',
                'full_width'     => true,
                'content'     => '<h2>' . esc_html__('Standard Post Format', 'kalisa') . '</h2>',
            ),
            array(
                'id'       => 'single-format-standard-layout',
                'type'     => 'select',
                'title'    => esc_html__('Standard Post Layout', 'kalisa'),
                'subtitle' => esc_html__('Select default layout for standard posts. You can customize settings for each layout below.', 'kalisa'),
                'desc'     => '',
                'options'  => array(
                    '1' => esc_html__('Layout 1', 'kalisa'),
                    '2' => esc_html__('Layout 2', 'kalisa'),
                    '3' => esc_html__('Layout 3', 'kalisa'),
                    '4' => esc_html__('Layout 4', 'kalisa'),
                    '5' => esc_html__('Layout 5', 'kalisa'),
                    '6' => esc_html__('Layout 6', 'kalisa'),
                    '7' => esc_html__('Layout 7', 'kalisa'),
                    '8' => esc_html__('Layout 8', 'kalisa'),
                    '9' => esc_html__('Layout 9', 'kalisa'),
                    '10' => esc_html__('Layout 10', 'kalisa'),
                    '11' => esc_html__('Layout 11', 'kalisa'),
                    '12' => esc_html__('Layout 12', 'kalisa'),
                    '13' => esc_html__('Layout 13', 'kalisa'),
                    '14' => esc_html__('Layout 14', 'kalisa'),
                    '15' => esc_html__('Layout 15', 'kalisa'),
                    '16' => esc_html__('Layout 16', 'kalisa'),


                ),
                'select2'  => array( 'allowClear' => false ),
                'default'  => '1',
            ),
            array(
                'id'       => 'subtitle-56784',
                'required' => array( 'single-format-standard-layout', '=', '1' ),
                'type'     => 'raw',
                'full_width'     => true,
                'content'     => '<h4>' . esc_html__('Layout 1 Settings', 'kalisa') . '</h4>',
            ),
            array(
                'id'       => 'single-format-standard-layout-1-img-position',
                'type'     => 'select',
                'required' => array( 'single-format-standard-layout', '=', '1' ),
                'title'    => esc_html__('Image Position', 'kalisa'),
                'subtitle' => esc_html__('Select image position.', 'kalisa'),
                'desc'     => '',
                'options'  => array(
                    'before' => esc_html__('Before Meta', 'kalisa'),
                    'after' => esc_html__('After Meta', 'kalisa'),
                ),
                'select2'  => array( 'allowClear' => false ),
                'default'  => 'before',
            ),
            array(
                'id'       => 'single-format-standard-layout-1-meta',
                'type'     => 'checkbox',
                'required' => array( 'single-format-standard-layout', '=', '1' ),
                'title'    => esc_html__('Post Meta', 'kalisa'),
                'subtitle' => esc_html__('Select post meta for this layout.', 'kalisa'),
                'desc'     => '',
                'options'  => array(
                    'author-name' => esc_html__('Author Name', 'kalisa'),
                    'author-avatar' => esc_html__('Author Avatar', 'kalisa'),
                    'date' => esc_html__('Date', 'kalisa'),
                    'date-updated' => esc_html__('Updated Date', 'kalisa'),
                    'category' => esc_html__('Category', 'kalisa'),
                    'comments' => esc_html__('Comments', 'kalisa'),
                    'views' => esc_html__('Views', 'kalisa'),
                    'reading-time' => esc_html__('Reading Time', 'kalisa'),
                    'excerpt' => esc_html__('Excerpt', 'kalisa'),
                ),
                'default' => array(
                    'author-name' => '1',
                    'author-avatar' => '1',
                    'date' => '1',
                    'date-updated' => '0',
                    'category' => '1',
                    'comments' => '1',
                    'views' => '1',
                    'reading-time' => '1',
                    'excerpt' => '0',
                )
            ),
            array(
                'id'       => 'single-format-standard-layout-1-full-img',
                'type'     => 'checkbox',
                'required' => array( 'single-format-standard-layout', '=', '1' ),
                'title'    => esc_html__('Full Image Size', 'kalisa'),
                'subtitle' => '',
                'desc'     => '',
                'default' => '0'
            ),
            array(
                'id'       => 'single-format-standard-layout-1-radius',
                'type'     => 'checkbox',
                'required' => array( 'single-format-standard-layout', '=', '1' ),
                'title'    => esc_html__('Image Radius', 'kalisa'),
                'subtitle' => '',
                'desc'     => '',
                'default' => '1'
            ),
            array(
                'id'       => 'single-format-standard-layout-1-shadow',
                'type'     => 'checkbox',
                'required' => array( 'single-format-standard-layout', '=', '1' ),
                'title'    => esc_html__('Image Shadow', 'kalisa'),
                'subtitle' => '',
                'desc'     => '',
                'default' => '1'
            ),

            array(
                'id'       => 'subtitle-83494',
                'required' => array( 'single-format-standard-layout', '=', '2' ),
                'type'     => 'raw',
                'full_width'     => true,
                'content'     => '<h4>' . esc_html__('Layout 2 Settings', 'kalisa') . '</h4>',
            ),
            array(
                'id'       => 'single-format-standard-layout-2-img-position',
                'type'     => 'select',
                'required' => array( 'single-format-standard-layout', '=', '2' ),
                'title'    => esc_html__('Image Position', 'kalisa'),
                'subtitle' => esc_html__('Select image position.', 'kalisa'),
                'desc'     => '',
                'options'  => array(
                    'before' => esc_html__('Before Meta', 'kalisa'),
                    'after' => esc_html__('After Meta', 'kalisa'),
                ),
                'select2'  => array( 'allowClear' => false ),
                'default'  => 'before',
            ),
            array(
                'id'       => 'single-format-standard-layout-2-meta',
                'type'     => 'checkbox',
                'required' => array( 'single-format-standard-layout', '=', '2' ),
                'title'    => esc_html__('Post Meta', 'kalisa'),
                'subtitle' => esc_html__('Select post meta for this layout.', 'kalisa'),
                'desc'     => '',
                'options'  => array(
                    'author-name' => esc_html__('Author Name', 'kalisa'),
                    'author-avatar' => esc_html__('Author Avatar', 'kalisa'),
                    'date' => esc_html__('Date', 'kalisa'),
                    'date-updated' => esc_html__('Updated Date', 'kalisa'),
                    'category' => esc_html__('Category', 'kalisa'),
                    'comments' => esc_html__('Comments', 'kalisa'),
                    'views' => esc_html__('Views', 'kalisa'),
                    'reading-time' => esc_html__('Reading Time', 'kalisa'),
                    'excerpt' => esc_html__('Excerpt', 'kalisa'),
                ),
                'default' => array(
                    'author-name' => '1',
                    'author-avatar' => '1',
                    'date' => '1',
                    'date-updated' => '0',
                    'category' => '1',
                    'comments' => '1',
                    'views' => '1',
                    'reading-time' => '1',
                    'excerpt' => '0',
                )
            ),
            array(
                'id'       => 'single-format-standard-layout-2-full-img',
                'type'     => 'checkbox',
                'required' => array( 'single-format-standard-layout', '=', '2' ),
                'title'    => esc_html__('Full Image Size', 'kalisa'),
                'subtitle' => '',
                'desc'     => '',
                'default' => '0'
            ),
            array(
                'id'       => 'single-format-standard-layout-2-radius',
                'type'     => 'checkbox',
                'required' => array( 'single-format-standard-layout', '=', '2' ),
                'title'    => esc_html__('Image Radius', 'kalisa'),
                'subtitle' => '',
                'desc'     => '',
                'default' => '1'
            ),
            array(
                'id'       => 'single-format-standard-layout-2-shadow',
                'type'     => 'checkbox',
                'required' => array( 'single-format-standard-layout', '=', '2' ),
                'title'    => esc_html__('Image Shadow', 'kalisa'),
                'subtitle' => '',
                'desc'     => '',
                'default' => '1'
            ),


            array(
                'id'       => 'subtitle-28826',
                'required' => array( 'single-format-standard-layout', '=', '3' ),
                'type'     => 'raw',
                'full_width'     => true,
                'content'     => '<h4>' . esc_html__('Layout 3 Settings', 'kalisa') . '</h4>',
            ),
            array(
                'id'       => 'single-format-standard-layout-3-meta',
                'type'     => 'checkbox',
                'required' => array( 'single-format-standard-layout', '=', '3' ),
                'title'    => esc_html__('Post Meta', 'kalisa'),
                'subtitle' => esc_html__('Select post meta for this layout.', 'kalisa'),
                'desc'     => '',
                'options'  => array(
                    'author-name' => esc_html__('Author Name', 'kalisa'),
                    'author-avatar' => esc_html__('Author Avatar', 'kalisa'),
                    'date' => esc_html__('Date', 'kalisa'),
                    'date-updated' => esc_html__('Updated Date', 'kalisa'),
                    'category' => esc_html__('Category', 'kalisa'),
                    'comments' => esc_html__('Comments', 'kalisa'),
                    'views' => esc_html__('Views', 'kalisa'),
                    'reading-time' => esc_html__('Reading Time', 'kalisa'),
                    'excerpt' => esc_html__('Excerpt', 'kalisa'),
                ),
                'default' => array(
                    'author-name' => '1',
                    'author-avatar' => '1',
                    'date' => '1',
                    'date-updated' => '0',
                    'category' => '1',
                    'comments' => '1',
                    'views' => '1',
                    'reading-time' => '1',
                    'excerpt' => '0',
                )
            ),



            array(
                'id'       => 'subtitle-26774',
                'required' => array( 'single-format-standard-layout', '=', '4' ),
                'type'     => 'raw',
                'full_width'     => true,
                'content'     => '<h4>' . esc_html__('Layout 4 Settings', 'kalisa') . '</h4>',
            ),
            array(
                'id'       => 'single-format-standard-layout-4-meta',
                'type'     => 'checkbox',
                'required' => array( 'single-format-standard-layout', '=', '4' ),
                'title'    => esc_html__('Post Meta', 'kalisa'),
                'subtitle' => esc_html__('Select post meta for this layout.', 'kalisa'),
                'desc'     => '',
                'options'  => array(
                    'author-name' => esc_html__('Author Name', 'kalisa'),
                    'author-avatar' => esc_html__('Author Avatar', 'kalisa'),
                    'date' => esc_html__('Date', 'kalisa'),
                    'date-updated' => esc_html__('Updated Date', 'kalisa'),
                    'category' => esc_html__('Category', 'kalisa'),
                    'comments' => esc_html__('Comments', 'kalisa'),
                    'views' => esc_html__('Views', 'kalisa'),
                    'reading-time' => esc_html__('Reading Time', 'kalisa'),
                    'excerpt' => esc_html__('Excerpt', 'kalisa'),
                ),
                'default' => array(
                    'author-name' => '1',
                    'author-avatar' => '1',
                    'date' => '1',
                    'date-updated' => '0',
                    'category' => '1',
                    'comments' => '1',
                    'views' => '1',
                    'reading-time' => '1',
                    'excerpt' => '0',
                )
            ),
            array(
                'id'       => 'single-format-standard-layout-4-bg',
                'type'     => 'color',
                'required' => array( 'single-format-standard-layout', '=', '4' ),
                'transparent'     => false,
                'title'    => esc_html__('Background Color', 'kalisa'),
                'subtitle' => esc_html__('Choose background color.', 'kalisa'),
                'desc'     => '',
                'default'  => '',
                'validate' => 'color',
            ),
            array(
                'id'       => 'single-format-standard-layout-4-radius',
                'type'     => 'checkbox',
                'required' => array( 'single-format-standard-layout', '=', '4' ),
                'title'    => esc_html__('Image Radius', 'kalisa'),
                'subtitle' => '',
                'desc'     => '',
                'default' => '1'
            ),




            array(
                'id'       => 'subtitle-11474',
                'required' => array( 'single-format-standard-layout', '=', '5' ),
                'type'     => 'raw',
                'full_width'     => true,
                'content'     => '<h4>' . esc_html__('Layout 5 Settings', 'kalisa') . '</h4>',
            ),
            array(
                'id'       => 'single-format-standard-layout-5-meta',
                'type'     => 'checkbox',
                'required' => array( 'single-format-standard-layout', '=', '5' ),
                'title'    => esc_html__('Post Meta', 'kalisa'),
                'subtitle' => esc_html__('Select post meta for this layout.', 'kalisa'),
                'desc'     => '',
                'options'  => array(
                    'author-name' => esc_html__('Author Name', 'kalisa'),
                    'author-avatar' => esc_html__('Author Avatar', 'kalisa'),
                    'date' => esc_html__('Date', 'kalisa'),
                    'date-updated' => esc_html__('Updated Date', 'kalisa'),
                    'category' => esc_html__('Category', 'kalisa'),
                    'comments' => esc_html__('Comments', 'kalisa'),
                    'views' => esc_html__('Views', 'kalisa'),
                    'reading-time' => esc_html__('Reading Time', 'kalisa'),
                    'excerpt' => esc_html__('Excerpt', 'kalisa'),
                ),
                'default' => array(
                    'author-name' => '1',
                    'author-avatar' => '1',
                    'date' => '1',
                    'date-updated' => '0',
                    'category' => '1',
                    'comments' => '1',
                    'views' => '1',
                    'reading-time' => '1',
                    'excerpt' => '0',
                )
            ),
            array(
                'id'       => 'single-format-standard-layout-5-full-img',
                'type'     => 'checkbox',
                'required' => array( 'single-format-standard-layout', '=', '5' ),
                'title'    => esc_html__('Full Image Size', 'kalisa'),
                'subtitle' => '',
                'desc'     => '',
                'default' => '0'
            ),
            array(
                'id'       => 'single-format-standard-layout-5-radius',
                'type'     => 'checkbox',
                'required' => array( 'single-format-standard-layout', '=', '5' ),
                'title'    => esc_html__('Image Radius', 'kalisa'),
                'subtitle' => '',
                'desc'     => '',
                'default' => '1'
            ),
            array(
                'id'       => 'single-format-standard-layout-5-shadow',
                'type'     => 'checkbox',
                'required' => array( 'single-format-standard-layout', '=', '5' ),
                'title'    => esc_html__('Image Shadow', 'kalisa'),
                'subtitle' => '',
                'desc'     => '',
                'default' => '1'
            ),


            array(
                'id'       => 'subtitle-74374',
                'required' => array( 'single-format-standard-layout', '=', '6' ),
                'type'     => 'raw',
                'full_width'     => true,
                'content'     => '<h4>' . esc_html__('Layout 6 Settings', 'kalisa') . '</h4>',
            ),
            array(
                'id'       => 'single-format-standard-layout-6-meta',
                'type'     => 'checkbox',
                'required' => array( 'single-format-standard-layout', '=', '6' ),
                'title'    => esc_html__('Post Meta', 'kalisa'),
                'subtitle' => esc_html__('Select post meta for this layout.', 'kalisa'),
                'desc'     => '',
                'options'  => array(
                    'author-name' => esc_html__('Author Name', 'kalisa'),
                    'author-avatar' => esc_html__('Author Avatar', 'kalisa'),
                    'date' => esc_html__('Date', 'kalisa'),
                    'date-updated' => esc_html__('Updated Date', 'kalisa'),
                    'category' => esc_html__('Category', 'kalisa'),
                    'comments' => esc_html__('Comments', 'kalisa'),
                    'views' => esc_html__('Views', 'kalisa'),
                    'reading-time' => esc_html__('Reading Time', 'kalisa'),
                    'excerpt' => esc_html__('Excerpt', 'kalisa'),
                ),
                'default' => array(
                    'author-name' => '1',
                    'author-avatar' => '1',
                    'date' => '1',
                    'date-updated' => '0',
                    'category' => '1',
                    'comments' => '1',
                    'views' => '1',
                    'reading-time' => '1',
                    'excerpt' => '0',
                )
            ),
            array(
                'id'       => 'single-format-standard-layout-6-bg',
                'type'     => 'color',
                'required' => array( 'single-format-standard-layout', '=', '6' ),
                'transparent'     => false,
                'title'    => esc_html__('Background Color', 'kalisa'),
                'subtitle' => esc_html__('Choose background color.', 'kalisa'),
                'desc'     => '',
                'default'  => '',
                'validate' => 'color',
            ),
            array(
                'id'       => 'single-format-standard-layout-6-full-img',
                'type'     => 'checkbox',
                'required' => array( 'single-format-standard-layout', '=', '6' ),
                'title'    => esc_html__('Full Image Size', 'kalisa'),
                'subtitle' => '',
                'desc'     => '',
                'default' => '0'
            ),
            array(
                'id'       => 'single-format-standard-layout-6-radius',
                'type'     => 'checkbox',
                'required' => array( 'single-format-standard-layout', '=', '6' ),
                'title'    => esc_html__('Image Radius', 'kalisa'),
                'subtitle' => '',
                'desc'     => '',
                'default' => '1'
            ),
            array(
                'id'       => 'single-format-standard-layout-6-shadow',
                'type'     => 'checkbox',
                'required' => array( 'single-format-standard-layout', '=', '6' ),
                'title'    => esc_html__('Image Shadow', 'kalisa'),
                'subtitle' => '',
                'desc'     => '',
                'default' => '1'
            ),


            array(
                'id'       => 'subtitle-99774',
                'required' => array( 'single-format-standard-layout', '=', '7' ),
                'type'     => 'raw',
                'full_width'     => true,
                'content'     => '<h4>' . esc_html__('Layout 7 Settings', 'kalisa') . '</h4>',
            ),
            array(
                'id'       => 'single-format-standard-layout-7-meta',
                'type'     => 'checkbox',
                'required' => array( 'single-format-standard-layout', '=', '7' ),
                'title'    => esc_html__('Post Meta', 'kalisa'),
                'subtitle' => esc_html__('Select post meta for this layout.', 'kalisa'),
                'desc'     => '',
                'options'  => array(
                    'author-name' => esc_html__('Author Name', 'kalisa'),
                    'author-avatar' => esc_html__('Author Avatar', 'kalisa'),
                    'date' => esc_html__('Date', 'kalisa'),
                    'date-updated' => esc_html__('Updated Date', 'kalisa'),
                    'category' => esc_html__('Category', 'kalisa'),
                    'comments' => esc_html__('Comments', 'kalisa'),
                    'views' => esc_html__('Views', 'kalisa'),
                    'reading-time' => esc_html__('Reading Time', 'kalisa'),
                    'excerpt' => esc_html__('Excerpt', 'kalisa'),
                ),
                'default' => array(
                    'author-name' => '1',
                    'author-avatar' => '1',
                    'date' => '1',
                    'date-updated' => '0',
                    'category' => '1',
                    'comments' => '1',
                    'views' => '1',
                    'reading-time' => '1',
                    'excerpt' => '0',
                )
            ),
            array(
                'id'       => 'single-format-standard-layout-7-bg',
                'type'     => 'color',
                'required' => array( 'single-format-standard-layout', '=', '7' ),
                'transparent'     => false,
                'title'    => esc_html__('Background Color', 'kalisa'),
                'subtitle' => esc_html__('Choose background color.', 'kalisa'),
                'desc'     => '',
                'default'  => '',
                'validate' => 'color',
            ),
            array(
                'id'       => 'single-format-standard-layout-7-full-img',
                'type'     => 'checkbox',
                'required' => array( 'single-format-standard-layout', '=', '7' ),
                'title'    => esc_html__('Full Image Size', 'kalisa'),
                'subtitle' => '',
                'desc'     => '',
                'default' => '0'
            ),
            array(
                'id'       => 'single-format-standard-layout-7-radius',
                'type'     => 'checkbox',
                'required' => array( 'single-format-standard-layout', '=', '7' ),
                'title'    => esc_html__('Image Radius', 'kalisa'),
                'subtitle' => '',
                'desc'     => '',
                'default' => '1'
            ),
            array(
                'id'       => 'single-format-standard-layout-7-shadow',
                'type'     => 'checkbox',
                'required' => array( 'single-format-standard-layout', '=', '7' ),
                'title'    => esc_html__('Image Shadow', 'kalisa'),
                'subtitle' => '',
                'desc'     => '',
                'default' => '1'
            ),


            array(
                'id'       => 'subtitle-18500',
                'required' => array( 'single-format-standard-layout', '=', '8' ),
                'type'     => 'raw',
                'full_width'     => true,
                'content'     => '<h4>' . esc_html__('Layout 8 Settings', 'kalisa') . '</h4>',
            ),
            array(
                'id'       => 'single-format-standard-layout-8-meta',
                'type'     => 'checkbox',
                'required' => array( 'single-format-standard-layout', '=', '8' ),
                'title'    => esc_html__('Post Meta', 'kalisa'),
                'subtitle' => esc_html__('Select post meta for this layout.', 'kalisa'),
                'desc'     => '',
                'options'  => array(
                    'author-name' => esc_html__('Author Name', 'kalisa'),
                    'author-avatar' => esc_html__('Author Avatar', 'kalisa'),
                    'date' => esc_html__('Date', 'kalisa'),
                    'date-updated' => esc_html__('Updated Date', 'kalisa'),
                    'category' => esc_html__('Category', 'kalisa'),
                    'comments' => esc_html__('Comments', 'kalisa'),
                    'views' => esc_html__('Views', 'kalisa'),
                    'reading-time' => esc_html__('Reading Time', 'kalisa'),
                    'excerpt' => esc_html__('Excerpt', 'kalisa'),
                ),
                'default' => array(
                    'author-name' => '1',
                    'author-avatar' => '1',
                    'date' => '1',
                    'date-updated' => '0',
                    'category' => '1',
                    'comments' => '1',
                    'views' => '1',
                    'reading-time' => '1',
                    'excerpt' => '0',
                )
            ),


            array(
                'id'       => 'subtitle-66890',
                'required' => array( 'single-format-standard-layout', '=', '9' ),
                'type'     => 'raw',
                'full_width'     => true,
                'content'     => '<h4>' . esc_html__('Layout 9 Settings', 'kalisa') . '</h4>',
            ),
            array(
                'id'       => 'single-format-standard-layout-9-meta',
                'type'     => 'checkbox',
                'required' => array( 'single-format-standard-layout', '=', '9' ),
                'title'    => esc_html__('Post Meta', 'kalisa'),
                'subtitle' => esc_html__('Select post meta for this layout.', 'kalisa'),
                'desc'     => '',
                'options'  => array(
                    'author-name' => esc_html__('Author Name', 'kalisa'),
                    'author-avatar' => esc_html__('Author Avatar', 'kalisa'),
                    'date' => esc_html__('Date', 'kalisa'),
                    'date-updated' => esc_html__('Updated Date', 'kalisa'),
                    'category' => esc_html__('Category', 'kalisa'),
                    'comments' => esc_html__('Comments', 'kalisa'),
                    'views' => esc_html__('Views', 'kalisa'),
                    'reading-time' => esc_html__('Reading Time', 'kalisa'),
                    'excerpt' => esc_html__('Excerpt', 'kalisa'),
                ),
                'default' => array(
                    'author-name' => '1',
                    'author-avatar' => '1',
                    'date' => '1',
                    'date-updated' => '0',
                    'category' => '1',
                    'comments' => '1',
                    'views' => '1',
                    'reading-time' => '1',
                    'excerpt' => '0',
                )
            ),
            array(
                'id'       => 'single-format-standard-layout-9-radius',
                'type'     => 'checkbox',
                'required' => array( 'single-format-standard-layout', '=', '9' ),
                'title'    => esc_html__('Image Radius', 'kalisa'),
                'subtitle' => '',
                'desc'     => '',
                'default' => '1'
            ),
            array(
                'id'       => 'single-format-standard-layout-9-shadow',
                'type'     => 'checkbox',
                'required' => array( 'single-format-standard-layout', '=', '9' ),
                'title'    => esc_html__('Image Shadow', 'kalisa'),
                'subtitle' => '',
                'desc'     => '',
                'default' => '1'
            ),


            array(
                'id'       => 'subtitle-61886',
                'required' => array( 'single-format-standard-layout', '=', '10' ),
                'type'     => 'raw',
                'full_width'     => true,
                'content'     => '<h4>' . esc_html__('Layout 10 Settings', 'kalisa') . '</h4>',
            ),
            array(
                'id'       => 'single-format-standard-layout-10-img-position',
                'type'     => 'select',
                'required' => array( 'single-format-standard-layout', '=', '10' ),
                'title'    => esc_html__('Image Position', 'kalisa'),
                'subtitle' => esc_html__('Select image position.', 'kalisa'),
                'desc'     => '',
                'options'  => array(
                    'before' => esc_html__('Before Meta', 'kalisa'),
                    'after' => esc_html__('After Meta', 'kalisa'),
                ),
                'select2'  => array( 'allowClear' => false ),
                'default'  => 'before',
            ),
            array(
                'id'       => 'single-format-standard-layout-10-meta',
                'type'     => 'checkbox',
                'required' => array( 'single-format-standard-layout', '=', '10' ),
                'title'    => esc_html__('Post Meta', 'kalisa'),
                'subtitle' => esc_html__('Select post meta for this layout.', 'kalisa'),
                'desc'     => '',
                'options'  => array(
                    'author-name' => esc_html__('Author Name', 'kalisa'),
                    'author-avatar' => esc_html__('Author Avatar', 'kalisa'),
                    'date' => esc_html__('Date', 'kalisa'),
                    'date-updated' => esc_html__('Updated Date', 'kalisa'),
                    'category' => esc_html__('Category', 'kalisa'),
                    'comments' => esc_html__('Comments', 'kalisa'),
                    'views' => esc_html__('Views', 'kalisa'),
                    'reading-time' => esc_html__('Reading Time', 'kalisa'),
                    'excerpt' => esc_html__('Excerpt', 'kalisa'),
                ),
                'default' => array(
                    'author-name' => '1',
                    'author-avatar' => '1',
                    'date' => '1',
                    'date-updated' => '0',
                    'category' => '1',
                    'comments' => '1',
                    'views' => '1',
                    'reading-time' => '1',
                    'excerpt' => '0',
                )
            ),
            array(
                'id'       => 'single-format-standard-layout-10-full-img',
                'type'     => 'checkbox',
                'required' => array( 'single-format-standard-layout', '=', '10' ),
                'title'    => esc_html__('Full Image Size', 'kalisa'),
                'subtitle' => '',
                'desc'     => '',
                'default' => '0'
            ),


            array(
                'id'       => 'subtitle-61855',
                'required' => array( 'single-format-standard-layout', '=', '11' ),
                'type'     => 'raw',
                'full_width'     => true,
                'content'     => '<h4>' . esc_html__('Layout 11 (No Image) Settings', 'kalisa') . '</h4>',
            ),
            array(
                'id'       => 'single-format-standard-layout-11-meta',
                'type'     => 'checkbox',
                'required' => array( 'single-format-standard-layout', '=', '11' ),
                'title'    => esc_html__('Post Meta', 'kalisa'),
                'subtitle' => esc_html__('Select post meta for this layout.', 'kalisa'),
                'desc'     => '',
                'options'  => array(
                    'author-name' => esc_html__('Author Name', 'kalisa'),
                    'author-avatar' => esc_html__('Author Avatar', 'kalisa'),
                    'date' => esc_html__('Date', 'kalisa'),
                    'date-updated' => esc_html__('Updated Date', 'kalisa'),
                    'category' => esc_html__('Category', 'kalisa'),
                    'comments' => esc_html__('Comments', 'kalisa'),
                    'views' => esc_html__('Views', 'kalisa'),
                    'reading-time' => esc_html__('Reading Time', 'kalisa'),
                    'excerpt' => esc_html__('Excerpt', 'kalisa'),
                ),
                'default' => array(
                    'author-name' => '1',
                    'author-avatar' => '1',
                    'date' => '1',
                    'date-updated' => '0',
                    'category' => '1',
                    'comments' => '1',
                    'views' => '1',
                    'reading-time' => '1',
                    'excerpt' => '0',
                )
            ),


            array(
                'id'       => 'subtitle-62010',
                'required' => array( 'single-format-standard-layout', '=', '12' ),
                'type'     => 'raw',
                'full_width'     => true,
                'content'     => '<h4>' . esc_html__('Layout 12 Settings', 'kalisa') . '</h4>',
            ),
            array(
                'id'       => 'single-format-standard-layout-12-meta',
                'type'     => 'checkbox',
                'required' => array( 'single-format-standard-layout', '=', '12' ),
                'title'    => esc_html__('Post Meta', 'kalisa'),
                'subtitle' => esc_html__('Select post meta for this layout.', 'kalisa'),
                'desc'     => '',
                'options'  => array(
                    'author-name' => esc_html__('Author Name', 'kalisa'),
                    'author-avatar' => esc_html__('Author Avatar', 'kalisa'),
                    'date' => esc_html__('Date', 'kalisa'),
                    'date-updated' => esc_html__('Updated Date', 'kalisa'),
                    'category' => esc_html__('Category', 'kalisa'),
                    'comments' => esc_html__('Comments', 'kalisa'),
                    'views' => esc_html__('Views', 'kalisa'),
                    'reading-time' => esc_html__('Reading Time', 'kalisa'),
                    'excerpt' => esc_html__('Excerpt', 'kalisa'),
                ),
                'default' => array(
                    'author-name' => '1',
                    'author-avatar' => '1',
                    'date' => '1',
                    'date-updated' => '0',
                    'category' => '1',
                    'comments' => '1',
                    'views' => '1',
                    'reading-time' => '1',
                    'excerpt' => '0',
                )
            ),



            array(
                'id'       => 'subtitle-62110',
                'required' => array( 'single-format-standard-layout', '=', '13' ),
                'type'     => 'raw',
                'full_width'     => true,
                'content'     => '<h4>' . esc_html__('Layout 13 Settings', 'kalisa') . '</h4>',
            ),
            array(
                'id'       => 'single-format-standard-layout-13-meta',
                'type'     => 'checkbox',
                'required' => array( 'single-format-standard-layout', '=', '13' ),
                'title'    => esc_html__('Post Meta', 'kalisa'),
                'subtitle' => esc_html__('Select post meta for this layout.', 'kalisa'),
                'desc'     => '',
                'options'  => array(
                    'author-name' => esc_html__('Author Name', 'kalisa'),
                    'author-avatar' => esc_html__('Author Avatar', 'kalisa'),
                    'date' => esc_html__('Date', 'kalisa'),
                    'date-updated' => esc_html__('Updated Date', 'kalisa'),
                    'category' => esc_html__('Category', 'kalisa'),
                    'comments' => esc_html__('Comments', 'kalisa'),
                    'views' => esc_html__('Views', 'kalisa'),
                    'reading-time' => esc_html__('Reading Time', 'kalisa'),
                    'excerpt' => esc_html__('Excerpt', 'kalisa'),
                ),
                'default' => array(
                    'author-name' => '1',
                    'author-avatar' => '1',
                    'date' => '1',
                    'date-updated' => '0',
                    'category' => '1',
                    'comments' => '1',
                    'views' => '1',
                    'reading-time' => '1',
                    'excerpt' => '0',
                )
            ),
            array(
                'id'       => 'single-format-standard-layout-13-radius',
                'type'     => 'checkbox',
                'required' => array( 'single-format-standard-layout', '=', '13' ),
                'title'    => esc_html__('Image Radius', 'kalisa'),
                'subtitle' => '',
                'desc'     => '',
                'default' => '1'
            ),
            array(
                'id'       => 'single-format-standard-layout-13-shadow',
                'type'     => 'checkbox',
                'required' => array( 'single-format-standard-layout', '=', '13' ),
                'title'    => esc_html__('Image Shadow', 'kalisa'),
                'subtitle' => '',
                'desc'     => '',
                'default' => '1'
            ),



            array(
                'id'       => 'subtitle-62210',
                'required' => array( 'single-format-standard-layout', '=', '14' ),
                'type'     => 'raw',
                'full_width'     => true,
                'content'     => '<h4>' . esc_html__('Layout 14 Settings', 'kalisa') . '</h4>',
            ),
            array(
                'id'       => 'single-format-standard-layout-14-meta',
                'type'     => 'checkbox',
                'required' => array( 'single-format-standard-layout', '=', '14' ),
                'title'    => esc_html__('Post Meta', 'kalisa'),
                'subtitle' => esc_html__('Select post meta for this layout.', 'kalisa'),
                'desc'     => '',
                'options'  => array(
                    'author-name' => esc_html__('Author Name', 'kalisa'),
                    'author-avatar' => esc_html__('Author Avatar', 'kalisa'),
                    'date' => esc_html__('Date', 'kalisa'),
                    'date-updated' => esc_html__('Updated Date', 'kalisa'),
                    'category' => esc_html__('Category', 'kalisa'),
                    'comments' => esc_html__('Comments', 'kalisa'),
                    'views' => esc_html__('Views', 'kalisa'),
                    'reading-time' => esc_html__('Reading Time', 'kalisa'),
                    'excerpt' => esc_html__('Excerpt', 'kalisa'),
                ),
                'default' => array(
                    'author-name' => '1',
                    'author-avatar' => '1',
                    'date' => '1',
                    'date-updated' => '0',
                    'category' => '1',
                    'comments' => '1',
                    'views' => '1',
                    'reading-time' => '1',
                    'excerpt' => '0',
                )
            ),
            array(
                'id'       => 'single-format-standard-layout-14-radius',
                'type'     => 'checkbox',
                'required' => array( 'single-format-standard-layout', '=', '14' ),
                'title'    => esc_html__('Image Radius', 'kalisa'),
                'subtitle' => '',
                'desc'     => '',
                'default' => '1'
            ),
            array(
                'id'       => 'single-format-standard-layout-14-shadow',
                'type'     => 'checkbox',
                'required' => array( 'single-format-standard-layout', '=', '14' ),
                'title'    => esc_html__('Image Shadow', 'kalisa'),
                'subtitle' => '',
                'desc'     => '',
                'default' => '1'
            ),



            array(
                'id'       => 'subtitle-65586',
                'required' => array( 'single-format-standard-layout', '=', '15' ),
                'type'     => 'raw',
                'full_width'     => true,
                'content'     => '<h4>' . esc_html__('Layout 15 Settings', 'kalisa') . '</h4>',
            ),
            array(
                'id'       => 'single-format-standard-layout-15-meta',
                'type'     => 'checkbox',
                'required' => array( 'single-format-standard-layout', '=', '15' ),
                'title'    => esc_html__('Post Meta', 'kalisa'),
                'subtitle' => esc_html__('Select post meta for this layout.', 'kalisa'),
                'desc'     => '',
                'options'  => array(
                    'author-name' => esc_html__('Author Name', 'kalisa'),
                    'author-avatar' => esc_html__('Author Avatar', 'kalisa'),
                    'date' => esc_html__('Date', 'kalisa'),
                    'date-updated' => esc_html__('Updated Date', 'kalisa'),
                    'category' => esc_html__('Category', 'kalisa'),
                    'comments' => esc_html__('Comments', 'kalisa'),
                    'views' => esc_html__('Views', 'kalisa'),
                    'reading-time' => esc_html__('Reading Time', 'kalisa'),
                    'excerpt' => esc_html__('Excerpt', 'kalisa'),
                ),
                'default' => array(
                    'author-name' => '1',
                    'author-avatar' => '1',
                    'date' => '1',
                    'date-updated' => '0',
                    'category' => '1',
                    'comments' => '1',
                    'views' => '1',
                    'reading-time' => '1',
                    'excerpt' => '0',
                )
            ),
            array(
                'id'       => 'single-format-standard-layout-15-bg',
                'type'     => 'color',
                'transparent'     => false,
                'required' => array( 'single-format-standard-layout', '=', '15' ),
                'title'    => esc_html__('Background Color', 'kalisa'),
                'subtitle' => esc_html__('Choose background color.', 'kalisa'),
                'desc'     => '',
                'default'  => '',
                'validate' => 'color',
            ),


            array(
                'id'       => 'subtitle-65500',
                'required' => array( 'single-format-standard-layout', '=', '16' ),
                'type'     => 'raw',
                'full_width'     => true,
                'content'     => '<h4>' . esc_html__('Layout 16 Settings', 'kalisa') . '</h4>',
            ),
            array(
                'id'       => 'single-format-standard-layout-16-meta',
                'type'     => 'checkbox',
                'required' => array( 'single-format-standard-layout', '=', '16' ),
                'title'    => esc_html__('Post Meta', 'kalisa'),
                'subtitle' => esc_html__('Select post meta for this layout.', 'kalisa'),
                'desc'     => '',
                'options'  => array(
                    'author-name' => esc_html__('Author Name', 'kalisa'),
                    'author-avatar' => esc_html__('Author Avatar', 'kalisa'),
                    'date' => esc_html__('Date', 'kalisa'),
                    'date-updated' => esc_html__('Updated Date', 'kalisa'),
                    'category' => esc_html__('Category', 'kalisa'),
                    'comments' => esc_html__('Comments', 'kalisa'),
                    'views' => esc_html__('Views', 'kalisa'),
                    'reading-time' => esc_html__('Reading Time', 'kalisa'),
                    'excerpt' => esc_html__('Excerpt', 'kalisa'),
                ),
                'default' => array(
                    'author-name' => '1',
                    'author-avatar' => '1',
                    'date' => '1',
                    'date-updated' => '0',
                    'category' => '1',
                    'comments' => '1',
                    'views' => '1',
                    'reading-time' => '1',
                    'excerpt' => '0',
                )
            ),
            array(
                'id'       => 'single-format-standard-layout-16-bg',
                'type'     => 'color',
                'transparent'     => false,
                'required' => array( 'single-format-standard-layout', '=', '16' ),
                'title'    => esc_html__('Background Color', 'kalisa'),
                'subtitle' => esc_html__('Choose background color.', 'kalisa'),
                'desc'     => '',
                'default'  => '',
                'validate' => 'color',
            ),
            array(
                'id'       => 'single-format-standard-layout-16-radius',
                'type'     => 'checkbox',
                'required' => array( 'single-format-standard-layout', '=', '16' ),
                'title'    => esc_html__('Image Radius', 'kalisa'),
                'subtitle' => '',
                'desc'     => '',
                'default' => '1'
            ),
            array(
                'id'       => 'single-format-standard-layout-16-shadow',
                'type'     => 'checkbox',
                'required' => array( 'single-format-standard-layout', '=', '16' ),
                'title'    => esc_html__('Image Shadow', 'kalisa'),
                'subtitle' => '',
                'desc'     => '',
                'default' => '1'
            ),




            array(
                'id'       => 'title-8545',
                'type'     => 'raw',
                'full_width'     => true,
                'content'     => '<h2>' . esc_html__('Gallery Post Format', 'kalisa') . '</h2>',
            ),
            array(
                'id'       => 'single-format-gallery-position',
                'type'     => 'select',
                'title'    => esc_html__('Gallery Position', 'kalisa'),
                'subtitle' => esc_html__('Select gallery position.', 'kalisa'),
                'desc'     => '',
                'options'  => array(
                    'inside' => esc_html__('Inside content', 'kalisa'),
                    'outside' => esc_html__('Outside Content', 'kalisa'),
                ),
                'select2'  => array( 'allowClear' => false ),
                'default'  => 'inside',
            ),
            array(
                'id'       => 'single-format-gallery-position-to-meta',
                'type'     => 'select',
                'title'    => esc_html__('Gallery Position To Meta', 'kalisa'),
                'subtitle' => esc_html__('Select gallery position.', 'kalisa'),
                'desc'     => '',
                'options'  => array(
                    'before' => esc_html__('Before Meta', 'kalisa'),
                    'after' => esc_html__('After Meta', 'kalisa'),
                ),
                'select2'  => array( 'allowClear' => false ),
                'default'  => 'before',
            ),
            array(
                'id'       => 'single-format-gallery-radius',
                'type'     => 'checkbox',
                'title'    => esc_html__('Image Radius', 'kalisa'),
                'subtitle' => '',
                'desc'     => '',
                'default' => '0'
            ),
            array(
                'id'       => 'single-format-gallery-shadow',
                'type'     => 'checkbox',
                'title'    => esc_html__('Image Shadow', 'kalisa'),
                'subtitle' => '',
                'desc'     => '',
                'default' => '0'
            ),

            array(
                'id'       => 'title-2475',
                'type'     => 'raw',
                'full_width'     => true,
                'content'     => '<h2>' . esc_html__('Quote Post Format', 'kalisa') . '</h2>',
            ),
            array(
                'id'       => 'single-format-quote-position',
                'type'     => 'select',
                'title'    => esc_html__('Quote Position', 'kalisa'),
                'subtitle' => esc_html__('Select quote position.', 'kalisa'),
                'desc'     => '',
                'options'  => array(
                    'inside' => esc_html__('Inside content', 'kalisa'),
                    'outside' => esc_html__('Outside Content', 'kalisa'),
                ),
                'select2'  => array( 'allowClear' => false ),
                'default'  => 'inside',
            ),
            array(
                'id'       => 'single-format-quote-position-to-meta',
                'type'     => 'select',
                'title'    => esc_html__('Quote Position To Meta', 'kalisa'),
                'subtitle' => esc_html__('Select quote position.', 'kalisa'),
                'desc'     => '',
                'options'  => array(
                    'before' => esc_html__('Before Meta', 'kalisa'),
                    'after' => esc_html__('After Meta', 'kalisa'),
                ),
                'select2'  => array( 'allowClear' => false ),
                'default'  => 'before',
            ),
            array(
                'id'       => 'single-format-quote-style',
                'type'     => 'select',
                'title'    => esc_html__('Quote Style', 'kalisa'),
                'subtitle' => esc_html__('Select quote style.', 'kalisa'),
                'desc'     => '',
                'options'  => array(
                    '1' => esc_html__('Style 1', 'kalisa'),
                    '2' => esc_html__('Style 2', 'kalisa'),
                    '3' => esc_html__('Style 3', 'kalisa'),
                    '4' => esc_html__('Style 4', 'kalisa'),
                ),
                'select2'  => array( 'allowClear' => false ),
                'default'  => '1',
            ),
            array(
                'id'       => 'single-format-quote-radius',
                'type'     => 'checkbox',
                'title'    => esc_html__('Quote Box Radius', 'kalisa'),
                'subtitle' => '',
                'desc'     => '',
                'default' => '1'
            ),
            array(
                'id'       => 'single-format-quote-shadow',
                'type'     => 'checkbox',
                'title'    => esc_html__('Quote Box Shadow', 'kalisa'),
                'subtitle' => '',
                'desc'     => '',
                'default' => '1'
            ),
            array(
                'id'       => 'single-format-quote-bg',
                'type'     => 'color',
                'transparent'     => false,
                'title'    => esc_html__('Quote Box Background', 'kalisa'),
                'subtitle' => esc_html__('Choose background color.', 'kalisa'),
                'desc'     => '',
                'default'  => '',
                'validate' => 'color',
            ),
            array(
                'id'       => 'single-format-quote-color',
                'type'     => 'color',
                'transparent'     => false,
                'title'    => esc_html__('Quote Box Text Color', 'kalisa'),
                'subtitle' => esc_html__('Choose text color.', 'kalisa'),
                'desc'     => '',
                'default'  => '',
                'validate' => 'color',
            ),

            array(
                'id'       => 'title-8569',
                'type'     => 'raw',
                'full_width'     => true,
                'content'     => '<h2>' . esc_html__('Link Post Format', 'kalisa') . '</h2>',
            ),
            array(
                'id'       => 'single-format-link-position',
                'type'     => 'select',
                'title'    => esc_html__('Link Position', 'kalisa'),
                'subtitle' => esc_html__('Select link position.', 'kalisa'),
                'desc'     => '',
                'options'  => array(
                    'inside' => esc_html__('Inside content', 'kalisa'),
                    'outside' => esc_html__('Outside Content', 'kalisa'),
                ),
                'select2'  => array( 'allowClear' => false ),
                'default'  => 'inside',
            ),
            array(
                'id'       => 'single-format-link-position-to-meta',
                'type'     => 'select',
                'title'    => esc_html__('Link Position To Meta', 'kalisa'),
                'subtitle' => esc_html__('Select link position.', 'kalisa'),
                'desc'     => '',
                'options'  => array(
                    'before' => esc_html__('Before Meta', 'kalisa'),
                    'after' => esc_html__('After Meta', 'kalisa'),
                ),
                'select2'  => array( 'allowClear' => false ),
                'default'  => 'before',
            ),
            array(
                'id'       => 'single-format-link-radius',
                'type'     => 'checkbox',
                'title'    => esc_html__('Link Box Radius', 'kalisa'),
                'subtitle' => '',
                'desc'     => '',
                'default' => '1'
            ),
            array(
                'id'       => 'single-format-link-shadow',
                'type'     => 'checkbox',
                'title'    => esc_html__('Link Box Shadow', 'kalisa'),
                'subtitle' => '',
                'desc'     => '',
                'default' => '1'
            ),
            array(
                'id'       => 'single-format-link-bg',
                'type'     => 'color',
                'transparent'     => false,
                'title'    => esc_html__('Link Box Background', 'kalisa'),
                'subtitle' => esc_html__('Choose background color.', 'kalisa'),
                'desc'     => '',
                'default'  => '',
                'validate' => 'color',
            ),
            array(
                'id'       => 'single-format-link-color',
                'type'     => 'color',
                'transparent'     => false,
                'title'    => esc_html__('Link Box Text Color', 'kalisa'),
                'subtitle' => esc_html__('Choose text color.', 'kalisa'),
                'desc'     => '',
                'default'  => '',
                'validate' => 'color',
            ),

            array(
                'id'       => 'title-2275',
                'type'     => 'raw',
                'full_width'     => true,
                'content'     => '<h2>' . esc_html__('Video Post Format', 'kalisa') . '</h2>',
            ),
            array(
                'id'       => 'single-format-video-position',
                'type'     => 'select',
                'title'    => esc_html__('Video Position', 'kalisa'),
                'subtitle' => esc_html__('Select video position.', 'kalisa'),
                'desc'     => '',
                'options'  => array(
                    'inside' => esc_html__('Inside content', 'kalisa'),
                    'outside' => esc_html__('Outside Content', 'kalisa'),
                ),
                'select2'  => array( 'allowClear' => false ),
                'default'  => 'inside',
            ),
            array(
                'id'       => 'single-format-video-position-to-meta',
                'type'     => 'select',
                'title'    => esc_html__('Video Position To Meta', 'kalisa'),
                'subtitle' => esc_html__('Select video position.', 'kalisa'),
                'desc'     => '',
                'options'  => array(
                    'before' => esc_html__('Before Meta', 'kalisa'),
                    'after' => esc_html__('After Meta', 'kalisa'),
                ),
                'select2'  => array( 'allowClear' => false ),
                'default'  => 'before',
            ),

            array(
                'id'       => 'title-8967',
                'type'     => 'raw',
                'full_width'     => true,
                'content'     => '<h2>' . esc_html__('Audio Post Format', 'kalisa') . '</h2>',
            ),
            array(
                'id'       => 'single-format-audio-position',
                'type'     => 'select',
                'title'    => esc_html__('Audio Position', 'kalisa'),
                'subtitle' => esc_html__('Select audio position.', 'kalisa'),
                'desc'     => '',
                'options'  => array(
                    'inside' => esc_html__('Inside content', 'kalisa'),
                    'outside' => esc_html__('Outside Content', 'kalisa'),
                ),
                'select2'  => array( 'allowClear' => false ),
                'default'  => 'inside',
            ),
            array(
                'id'       => 'single-format-audio-position-to-meta',
                'type'     => 'select',
                'title'    => esc_html__('Audio Position To Meta', 'kalisa'),
                'subtitle' => esc_html__('Select audio position.', 'kalisa'),
                'desc'     => '',
                'options'  => array(
                    'before' => esc_html__('Before Meta', 'kalisa'),
                    'after' => esc_html__('After Meta', 'kalisa'),
                ),
                'select2'  => array( 'allowClear' => false ),
                'default'  => 'before',
            ),




        )
    ) );


    Redux::set_section( $opt_name, array(
        'title'            => esc_html__('Blog Archive', 'kalisa'),
        'id'               => 'blog_section',
        'desc'             => esc_html__('Blog settings', 'kalisa'),
        'subsection'       => false,
        'icon'             => 'el el-th-list',
        'fields'           => array(
            array(
                'id'       => 'archive-template',
                'type'     => 'select',
                'title'    => esc_html__('Blog Archive Template', 'kalisa'),
                'subtitle' => esc_html__('Select template for blog archive.', 'kalisa'),
                'data'  => 'callback',
                'args' => 'rivax_get_templates_list',
                'desc'     => sprintf(esc_html__('You can create your custom template in %1$s Rivax Templates %2$s section.', 'kalisa'), '<a target="_blank" href="' . admin_url("edit.php?post_type=rivax-template") . '"><b>', '</b></a>'),
                'default' => '0',
                'select2'  => array( 'allowClear' => false ),
            ),

	        array(
		        'id'       => 'subtitle-6340587',
		        'type'     => 'raw',
		        'full_width'     => true,
		        'content'     => '<h4>' . esc_html__('Search Settings', 'kalisa') . '</h4>',
	        ),
	        array(
		        'id'       => 'search-post-types',
		        'type'     => 'select',
		        'multi'    => true,
		        'title'    => esc_html__('Search Post Types', 'kalisa'),
		        'subtitle' => esc_html__('Limit search for custom post types.', 'kalisa'),
		        'data'  => 'post_types',
		        'desc'     => esc_html__('WordPress search in all post types by default.', 'kalisa'),
				'args'  => array(
						'exclude_from_search'      => false,
					),
	        ),

            array(
                'id'       => 'subtitle-60587',
                'type'     => 'raw',
                'full_width'     => true,
                'content'     => '<h4>' . esc_html__('Archive Title Settings', 'kalisa') . '</h4>',
            ),
            array(
                'id'       => 'blog-archive-title-radius',
                'type'     => 'checkbox',
                'title'    => esc_html__('Archive Title Section Radius', 'kalisa'),
                'subtitle' => '',
                'desc'     => '',
                'default' => '1'
            ),
            array(
                'id'       => 'blog-archive-title-shadow',
                'type'     => 'checkbox',
                'title'    => esc_html__('Archive Title Section Shadow', 'kalisa'),
                'subtitle' => '',
                'desc'     => '',
                'default' => '0'
            ),
            array(
                'id'       => 'blog-archive-title-bg',
                'type'     => 'color',
                'transparent'     => false,
                'title'    => esc_html__('Archive Title Section Background', 'kalisa'),
                'subtitle' => '',
                'desc'     => '',
                'default'  => '',
                'validate' => 'color',
            ),
            array(
                'id'       => 'blog-archive-title-color',
                'type'     => 'color',
                'transparent'     => false,
                'title'    => esc_html__('Archive Title Section Color', 'kalisa'),
                'subtitle' => '',
                'desc'     => '',
                'default'  => '',
                'validate' => 'color',
            ),
            array(
                'id'       => 'blog-archive-title-padding',
                'type'     => 'spacing',
                'mode'     => 'padding',
                'units'    => 'px',
                'display_units' => false,
                'title'    => esc_html__('Archive Title Section Padding (px)', 'kalisa'),
                'subtitle' => '',
                'desc'     => '',
                'default'  => ''
            ),

        )
    ) );


  

    Redux::set_section( $opt_name, array(
        'title'            => esc_html__('Page 404', 'kalisa'),
        'id'               => 'page404_section',
        'desc'             => esc_html__('Page 404 settings', 'kalisa'),
        'subsection'       => false,
        'icon'             => 'el el-ban-circle',
        'fields'           => array(
            array(
                'id'       => 'page-404-template',
                'type'     => 'select',
                'title'    => esc_html__('Page 404 Template', 'kalisa'),
                'subtitle' => esc_html__('Select template for page 404.', 'kalisa'),
                'data'  => 'callback',
                'args' => 'rivax_get_templates_list',
                'desc'     => sprintf(esc_html__('You can create your custom template in %1$s Rivax Templates %2$s section.', 'kalisa'), '<a target="_blank" href="' . admin_url("edit.php?post_type=rivax-template") . '"><b>', '</b></a>'),
                'default' => '0',
                'select2'  => array( 'allowClear' => false ),
            ),

        )
    ) );




    Redux::set_section( $opt_name, array(
        'title'            => esc_html__('AMP', 'kalisa'),
        'id'               => 'amp_section',
        'desc'     => sprintf(esc_html__('If you interested to have an AMP version for your site, please install the %1$s AMP Plugin %2$s. Select Reader Mode for template and Legacy theme and select Posts for Supported Templates.', 'kalisa'), '<a target="_blank" href="https://wordpress.org/plugins/amp/"><b>', '</b></a>'),
        'subsection'       => false,
        'icon'             => 'el el-compass',
        'fields'           => array(
            array(
                'id'       => 'amp-logo',
                'type'     => 'media',
                'url'      => true,
                'title'    => esc_html__('AMP Logo', 'kalisa'),
                'subtitle' => esc_html__('Select your logo for the header.', 'kalisa'),
                'desc'     => '',
                'default'  => '',
            ),
            array(
                'id'       => 'amp-logo-width',
                'type'     => 'slider',
                'title'    => esc_html__('AMP Logo Width', 'kalisa'),
                'subtitle' => esc_html__('Select the logo width.', 'kalisa'),
                'desc'     => esc_html__('Default value: 100', 'kalisa'),
                'default'  => 100,
                'min'       => 60,
                'step'      => 5,
                'max'       => 300,
            ),
            array(
                'id'       => 'amp-sidebar-search',
                'type'     => 'switch',
                'on'     => esc_html__('Enable', 'kalisa'),
                'off'     => esc_html__('Disable', 'kalisa'),
                'title'    => esc_html__('Sidebar Search', 'kalisa'),
                'desc'     => '',
                'default'  => true,
            ),
            array(
                'id'       => 'amp-back-top',
                'type'     => 'switch',
                'on'     => esc_html__('Enable', 'kalisa'),
                'off'     => esc_html__('Disable', 'kalisa'),
                'title'    => esc_html__('Footer Back to Top', 'kalisa'),
                'desc'     => '',
                'default'  => true,
            ),
            array(
                'id'       => 'amp-copyright',
                'type'     => 'text',
                'title'    => esc_html__('Footer Copyright', 'kalisa'),
                'default'  => esc_html__('Designed by Rivax Studio. All Rights Reserved.', 'kalisa'),
            ),

        )
    ) );




    Redux::set_section( $opt_name, array(
        'title'            => esc_html__('Dark Mode', 'kalisa'),
        'id'               => 'dark_mode_section',
        'desc'             => esc_html__('Dark Mode settings', 'kalisa'),
        'subsection'       => false,
        'icon'             => 'el el-idea-alt',
        'fields'           => array(
            array(
                'id'       => 'dark-mode',
                'type'     => 'switch',
                'on'     => esc_html__('Enable', 'kalisa'),
                'off'     => esc_html__('Disable', 'kalisa'),
                'title'    => esc_html__('Dark Mode', 'kalisa'),
                'subtitle'     => esc_html__('Enable dark mode for your site.', 'kalisa'),
                'default'  => false,
            ),
			array(
                'id'       => 'default-dark-mode',
                'type'     => 'switch',
                'on'     => esc_html__('Enable', 'kalisa'),
                'off'     => esc_html__('Disable', 'kalisa'),
                'title'    => esc_html__('Default Dark Mode', 'kalisa'),
                'subtitle'     => esc_html__('Load site in dark mode as default.', 'kalisa'),
                'required' => array( 'dark-mode', '=', '1' ),
            ),
            array(
                'id'       => 'accent-color-dark',
                'type'     => 'color',
                'transparent'     => false,
                'title'    => esc_html__('Accent Color', 'kalisa'),
                'subtitle' => '',
                'desc'     => '',
                'default'  => '',
                'validate' => 'color',
                'required' => array( 'dark-mode', '=', '1' ),
            ),
            array(
                'id'       => 'second-color-dark',
                'type'     => 'color',
                'transparent'     => false,
                'title'    => esc_html__('Second Color', 'kalisa'),
                'subtitle' => '',
                'desc'     => '',
                'default'  => '',
                'validate' => 'color',
                'required' => array( 'dark-mode', '=', '1' ),
            ),
            array(
                'id'       => 'body-bg-dark',
                'type'     => 'color',
                'transparent'     => false,
                'title'    => esc_html__('Body Background Color', 'kalisa'),
                'subtitle' => '',
                'desc'     => '',
                'default'  => '',
                'validate' => 'color',
                'required' => array( 'dark-mode', '=', '1' ),
            ),
            array(
                'id'       => 'body-color-dark',
                'type'     => 'color',
                'transparent'     => false,
                'title'    => esc_html__('Body Text Color', 'kalisa'),
                'subtitle' => '',
                'desc'     => '',
                'default'  => '',
                'validate' => 'color',
                'required' => array( 'dark-mode', '=', '1' ),
            ),
            array(
                'id'       => 'heading-color-dark',
                'type'     => 'color',
                'transparent'     => false,
                'title'    => esc_html__('Headings Color', 'kalisa'),
                'subtitle' => '',
                'desc'     => '',
                'default'  => '',
                'validate' => 'color',
                'required' => array( 'dark-mode', '=', '1' ),
            ),
            array(
                'id'       => 'single-category-bg-dark',
                'type'     => 'color',
                'transparent'     => false,
                'title'    => esc_html__('Single Post Category Background', 'kalisa'),
                'subtitle' => '',
                'desc'     => '',
                'default'  => '',
                'validate' => 'color',
                'required' => array( 'dark-mode', '=', '1' ),
            ),
            array(
                'id'       => 'single-category-bg-hover-dark',
                'type'     => 'color',
                'transparent'     => false,
                'title'    => esc_html__('Single Post Category Background Hover', 'kalisa'),
                'subtitle' => '',
                'desc'     => '',
                'default'  => '',
                'validate' => 'color',
                'required' => array( 'dark-mode', '=', '1' ),
            ),
            array(
                'id'       => 'button-bg-hover-dark',
                'type'     => 'color',
                'transparent'     => false,
                'title'    => esc_html__('Button Background Hover', 'kalisa'),
                'subtitle' => '',
                'desc'     => '',
                'default'  => '',
                'validate' => 'color',
                'required' => array( 'dark-mode', '=', '1' ),
            ),

        )
    ) );


    Redux::set_section( $opt_name, array(
        'title'            => esc_html__('Privacy Notice', 'kalisa'),
        'id'               => 'privacy_notice_section',
        'desc'             => esc_html__('Privacy notice settings', 'kalisa'),
        'subsection'       => false,
        'icon'             => 'el el-bullhorn',
        'fields'           => array(
            array(
                'id'       => 'privacy-notice',
                'type'     => 'switch',
                'on'     => esc_html__('Enable', 'kalisa'),
                'off'     => esc_html__('Disable', 'kalisa'),
                'title'    => esc_html__('Privacy Notice', 'kalisa'),
                'subtitle'     => esc_html__('Show privacy notice popup.', 'kalisa'),
                'default'  => false,
            ),
            array(
                'id'       => 'privacy-text',
                'type'     => 'textarea',
                'title'    => esc_html__('Privacy Notice Text', 'kalisa'),
                'subtitle' => esc_html__('Input your privacy or cookie notice text, HTML allowed.', 'kalisa'),
                'desc'     => '',
                'default'  => html_entity_decode( esc_html__( 'Our site uses cookies. By using this site, you agree to the <a href="#">Privacy Policy</a> and <a href="#">Terms of Use</a>.', 'kalisa' ) ),
                'required' => array( 'privacy-notice', '=', '1' ),
            ),
            array(
                'id'       => 'privacy-btn-text',
                'type'     => 'text',
                'title'    => esc_html__('Button Text', 'kalisa'),
                'subtitle' => '',
                'default' => esc_html__('Accept', 'kalisa'),
                'required' => array( 'privacy-notice', '=', '1' ),
            ),
            array(
                'id'       => 'privacy-position',
                'type'     => 'select',
                'title'    => esc_html__('Privacy Notice Position', 'kalisa'),
                'subtitle' => esc_html__('Select position for privacy notice bar.', 'kalisa'),
                'desc'     => '',
                'options'  => array(
                    'bottom-left' => esc_html__('Bottom Left', 'kalisa'),
                    'bottom-center' => esc_html__('Bottom Center', 'kalisa'),
                ),
                'select2'  => array( 'allowClear' => false ),
                'default'  => 'bottom-left',
                'required' => array( 'privacy-notice', '=', '1' ),
            ),
            array(
                'id'       => 'privacy-color',
                'type'     => 'color',
                'transparent'     => false,
                'title'    => esc_html__('Color', 'kalisa'),
                'subtitle' => '',
                'desc'     => '',
                'default'  => '',
                'validate' => 'color',
                'required' => array( 'privacy-notice', '=', '1' ),
            ),
            array(
                'id'       => 'privacy-bg',
                'type'     => 'color',
                'transparent'     => false,
                'title'    => esc_html__('Background', 'kalisa'),
                'subtitle' => '',
                'desc'     => '',
                'default'  => '',
                'validate' => 'color',
                'required' => array( 'privacy-notice', '=', '1' ),
            ),
            array(
                'id'       => 'privacy-color-dark',
                'type'     => 'color',
                'transparent'     => false,
                'title'    => esc_html__('Color - Dark Mode', 'kalisa'),
                'subtitle' => '',
                'desc'     => '',
                'default'  => '',
                'validate' => 'color',
                'required' => array( 'privacy-notice', '=', '1' ),
            ),
            array(
                'id'       => 'privacy-bg-dark',
                'type'     => 'color',
                'transparent'     => false,
                'title'    => esc_html__('Background - Dark Mode', 'kalisa'),
                'subtitle' => '',
                'desc'     => '',
                'default'  => '',
                'validate' => 'color',
                'required' => array( 'privacy-notice', '=', '1' ),
            ),

        )
    ) );
	
	
	Redux::set_section( $opt_name, array(
        'title'            => esc_html__('Breadcrumb', 'kalisa'),
        'id'               => 'breadcrumb_section',
        'desc'             => esc_html__('Breadcrumb Bar settings', 'kalisa'),
        'subsection'       => false,
        'icon'             => 'el el-bold',
        'fields'           => array(
            array(
                'id'       => 'breadcrumb',
                'type'     => 'switch',
                'on'     => esc_html__('Enable', 'kalisa'),
                'off'     => esc_html__('Disable', 'kalisa'),
                'title'    => esc_html__('Breadcrumb', 'kalisa'),
                'subtitle'     => esc_html__('Show breadcrumb bar.', 'kalisa'),
                'default'  => false,
            ),
            array(
                'id'       => 'breadcrumb-schema',
                'type'     => 'switch',
                'on'     => esc_html__('Enable', 'kalisa'),
                'off'     => esc_html__('Disable', 'kalisa'),
                'title'    => esc_html__('Breadcrumb Schema', 'kalisa'),
                'subtitle'     => esc_html__('Output breadcrumb structure data.', 'kalisa'),
                'default'  => false,
                'required' => array( 'breadcrumb', '=', '1' ),
            ),

        )
    ) );


	Redux::set_section( $opt_name, array(
		'title'            => esc_html__('Credentials', 'kalisa'),
		'id'               => 'credentials_section',
		'desc'             => esc_html__('Credentials settings', 'kalisa'),
		'subsection'       => false,
		'icon'             => 'el el-globe',
		'fields'           => array(
			array(
				'id'       => 'mailchimp-api-key',
				'type'     => 'text',
				'title'    => esc_html__('Mailchimp Api Key', 'kalisa'),
				'desc'     => sprintf(esc_html__('The API key for connecting with your Mailchimp account. %1$s Get your API key here. %2$s', 'kalisa'), '<a target="_blank" href="https://admin.mailchimp.com/account/api"><b>', '</b></a>'),
			),
			array(
				'id'       => 'mailchimp-double-opt-in',
				'type'     => 'switch',
				'on'     => esc_html__('Enable', 'kalisa'),
				'off'     => esc_html__('Disable', 'kalisa'),
				'title'    => esc_html__('Enable Mailchimp Double Opt In?', 'kalisa'),
			),

		)
	) );


	Redux::set_section( $opt_name, array(
		'title'            => esc_html__('Performance', 'kalisa'),
		'id'               => 'performance_section',
		'desc'             => esc_html__('Performance settings', 'kalisa'),
		'subsection'       => false,
		'icon'             => 'el el-broom',
		'fields'           => array(
			array(
				'id'       => 'disable-elementor-google-font',
				'type'     => 'switch',
				'on'     => esc_html__('Enable', 'kalisa'),
				'off'     => esc_html__('Disable', 'kalisa'),
				'title'    => esc_html__('Disable Load Elementor Google Font', 'kalisa'),
				'desc'    => esc_html__('If you don\'t use google fonts from the elementor, enable this option to prevent loading unused google fonts.', 'kalisa'),
			),
			array(
				'id'       => 'disable-emojis',
				'type'     => 'switch',
				'on'     => esc_html__('Enable', 'kalisa'),
				'off'     => esc_html__('Disable', 'kalisa'),
				'title'    => esc_html__('Disable Emojis', 'kalisa'),
				'desc'    => esc_html__('If you don\'t use emojis, enable this option to disable emojis.', 'kalisa'),
			),
			array(
				'id'       => 'disable-woocommerce-assets-out-of-shop',
				'type'     => 'switch',
				'on'     => esc_html__('Enable', 'kalisa'),
				'off'     => esc_html__('Disable', 'kalisa'),
				'title'    => esc_html__('Disable Woocommerce Assets out Of Shop', 'kalisa'),
				'desc'    => esc_html__('By default woocommerce css/js load on entire site. Enable this option to load them just on woocommerce pages.', 'kalisa'),
			),
			array(
				'id'       => 'disable-gutenberg-assets',
				'type'     => 'switch',
				'on'     => esc_html__('Enable', 'kalisa'),
				'off'     => esc_html__('Disable', 'kalisa'),
				'title'    => esc_html__('Disable Gutenberg Assets Out of Posts', 'kalisa'),
				'desc'    => esc_html__('By default gutenberg css load on entire site. Enable this option to disable load them from homepage, category & tag archives and pages build with Elementor.', 'kalisa'),
			),
			array(
				'id'       => 'disable-jquery-migrate',
				'type'     => 'switch',
				'on'     => esc_html__('Enable', 'kalisa'),
				'off'     => esc_html__('Disable', 'kalisa'),
				'title'    => esc_html__('Disable Jquery Migrate', 'kalisa'),
				'desc'    => esc_html__('By default Wordpress load Jquery Migrate. Enable this option to disable load it.', 'kalisa'),
			),
            array(
                'id'      => 'disable-xmlrpc',
                'type'    => 'switch',
                'on'      => esc_html__('Enable', 'kalisa'),
                'off'     => esc_html__('Disable', 'kalisa'),
                'title'   => esc_html__('Disable XML-RPC + Pingback', 'kalisa'),
                'desc'    => esc_html__('Disable support for third-party application access.', 'kalisa'),
            ),
            array(
                'id'      => 'disable-rsdlink',
                'type'    => 'switch',
                'on'      => esc_html__('Enable', 'kalisa'),
                'off'     => esc_html__('Disable', 'kalisa'),
                'title'   => esc_html__('Disable RSD', 'kalisa'),
                'desc'    => esc_html__('Disable the Really Simple Discovery (RSD) tag. If you edit your site from your browser then you do not need it.', 'kalisa'),
            ),
            array(
                'id'      => 'disable-shortlink',
                'type'    => 'switch',
                'on'      => esc_html__('Enable', 'kalisa'),
                'off'     => esc_html__('Disable', 'kalisa'),
                'title'   => esc_html__('Disable Short Link', 'kalisa'),
                'desc'    => esc_html__('Disable the Short Link from the head.', 'kalisa'),
            ),
            array(
                'id'      => 'disable-rssfeeds',
                'type'    => 'switch',
                'on'      => esc_html__('Enable', 'kalisa'),
                'off'     => esc_html__('Disable', 'kalisa'),
                'title'   => esc_html__('Disable RSS Feeds', 'kalisa'),
                'desc'    => esc_html__('Disable the RSS feed links and disable it.', 'kalisa'),
            ),
            array(
                'id'      => 'disable-generator-tag',
                'type'    => 'switch',
                'on'      => esc_html__('Enable', 'kalisa'),
                'off'     => esc_html__('Disable', 'kalisa'),
                'title'   => esc_html__('Disable Generator Tag', 'kalisa'),
                'desc'    => esc_html__('Disable the generator tag.', 'kalisa'),
            ),
            array(
                'id'      => 'disable-rest-api',
                'type'    => 'switch',
                'on'      => esc_html__('Enable', 'kalisa'),
                'off'     => esc_html__('Disable', 'kalisa'),
                'title'   => esc_html__('Disable REST API', 'kalisa'),
                'desc'    => esc_html__('Disable REST API for none logged in users. Some plugins need Rest API. If your plugins are not working correctly, disable this option.', 'kalisa'),
            ),
            array(
                'id'      => 'disable-revisions',
                'type'    => 'switch',
                'on'      => esc_html__('Enable', 'kalisa'),
                'off'     => esc_html__('Disable', 'kalisa'),
                'title'   => esc_html__('Disable Revisions', 'kalisa'),
                'desc'    => esc_html__('Reduce your database size by not storing revisions of posts.', 'kalisa'),
            ),
            array(
                'id'      => 'disable-oembed',
                'type'    => 'switch',
                'on'      => esc_html__('Enable', 'kalisa'),
                'off'     => esc_html__('Disable', 'kalisa'),
                'title'   => esc_html__('Disable Oembeds', 'kalisa'),
                'desc'    => esc_html__('Prevent other websites from embedding your site.', 'kalisa'),
            ),

		)
	) );
 


}