(function($){

    'use strict';


    function isScrolledIntoViewport(elem) {
        var docViewTop = $(window).scrollTop();
        var docViewBottom = docViewTop + $(window).height();

        var elemTop = $(elem).offset().top;
        var elemBottom = elemTop + $(elem).height();

        return ((elemBottom <= docViewBottom) && (elemTop >= docViewTop));
    }

    // Site Preload & Fix transitions on load
    $(window).on('load', function() {
        $("body").addClass("site-loaded");
    });


    // Smooth Scroll
    if( typeof SmoothScroll == 'function' && $('body').hasClass('rivax-smooth-scroll') ) {
        SmoothScroll({ keyboardSupport: false });
    }


    // Post Reading Progress Indicator
    if($('.post-reading-progress-indicator').length) {
        $(window).on('scroll', function () {
            let docHeight = $("body").height();
            let winHeight = $(window).height();
            let viewport = docHeight - winHeight;
            let scrollPos = $(window).scrollTop();
            let scrollPercent = (scrollPos / viewport) * 100;
            $(".post-reading-progress-indicator span").css("width", scrollPercent + "%");

        });
    }


    // Offcanvas
    $('.offcanvas-container').on('click', function (e) {
        e.stopPropagation();
    });
    $('body').on('click', '.offcanvas-opener', function (e) {
        e.stopPropagation();
        $(this).closest('.rivax-offcanvas').find('.offcanvas-wrapper').addClass('open');
    });

    $('body, .offcanvas-closer').on('click', function (e) {
        $('.offcanvas-wrapper').removeClass('open');
    });

    // Popup Search
    $('body').on('click', '.popup-search-opener', function (e) {
        e.stopPropagation();
        $(this).closest('.popup-search-wrapper').find('.popup-search').addClass('open');
    });

    $('.popup-search-container').on('click', function (e) {
        e.stopPropagation();
    });

    $('body, .popup-search-closer').on('click', function (e) {
        $('.popup-search').removeClass('open');
    });



    // Sticky Header
    $(window).on('scroll', function () {

        if ( $('#site-sticky-header').length == 0 ) { // Check sticky header is enabled
            return;
        }

        var stickyPos = $('#site-header').outerHeight() + 500;
        var scroll = $(window).scrollTop();

        if( scroll > stickyPos ) {
            $('#site-sticky-header').addClass('fixed');

            // Smart Sticky Sidebar & Elementor Column
            var stickyHeight = $('#site-sticky-header').outerHeight();
            $('.sidebar-container.sticky .sidebar-container-inner, .e-con.rivax-sticky-column').css('top', stickyHeight + 10);
        }
        else {
            $('#site-sticky-header').removeClass('fixed');
            $('#site-sticky-header .popup-search').removeClass('open');
            $('#site-sticky-header .offcanvas-wrapper').removeClass('open');

            // Smart Sticky Sidebar & Elementor Column
            $('.sidebar-container.sticky .sidebar-container-inner, .e-con.rivax-sticky-column').css('top', 10);
        }
    });


	// Header Nav prevent # jump
	$('.rivax-header-nav li > a[href="#"]').on('click', function (e) {
        e.preventDefault();
    });
	
	
    // Header Vertical Nav
    $('.rivax-header-v-nav li.menu-item-has-children > a').on('click', function (e) {
        e.preventDefault();
        $(this).siblings('.sub-menu').slideToggle();
    });




    // Header Mega Menu
	$('.rivax-header-nav .sub-menu.mega-menu-content').css('display', 'block');
    $('.rivax-header-nav li.rivax-mega-menu-4-col > .sub-menu').css('display', 'flex');
    $('body').on('mouseenter', '.rivax-header-nav li.rivax-mega-menu-item, .rivax-header-nav li.rivax-mega-menu-4-col', function() {

        var con = $(this).closest('div[data-elementor-type="wp-post"] > .e-con, div[data-elementor-type="wp-page"] > .e-con');


        // $('body').hasClass('elementor-editor-active')
        if(con.length == 0) {
            con = $(this).closest('div[data-elementor-type="wp-post"] .elementor-section-wrap > .e-con, div[data-elementor-type="wp-page"] .elementor-section-wrap > .e-con');
        }


        if(con.length == 0) {
            return;
        }

        if( con.hasClass('e-con-boxed') ) {
            con = con.children('.e-con-inner');
        }

        var megaMenuWidth = con.width();

        var subMenu = $(this).children('.sub-menu');
        subMenu.css('width', megaMenuWidth);

        var menuPos = $(this).closest('.rivax-header-nav').offset().left;
        var paddingLeft = ( con.innerWidth() - con.width() ) / 2;
        var elementorContainerPos = con.offset().left + paddingLeft;

        if( $('body').hasClass('rtl') ) {
            var menuRightPos = menuPos + $(this).closest('.rivax-header-nav').width();
            var elementorContainerRightPos = elementorContainerPos + megaMenuWidth;

            subMenu.css('right', parseInt(menuRightPos - elementorContainerRightPos));

        }
        else {
            subMenu.css('left', parseInt(elementorContainerPos - menuPos));
        }


    });




    // Back to Top Button
    $(window).on('scroll', function (e) {

        var showPos = $('#site-header').outerHeight() + 200;
        var scroll = $(window).scrollTop();

        if( scroll > showPos ) {
            $('#back-to-top').addClass('show');
        }
        else {
            $('#back-to-top').removeClass('show');
        }

    });

    $('#back-to-top').on('click', function(e) {
        $('body,html').animate({scrollTop:0},800);
    });


    // Fixed Next And Previous Posts
    $(window).on('scroll', function (e) {

        var scroll = $(window).scrollTop();

        if( scroll > 900 ) {
            $('.single-fixed-next-prev-posts').addClass('show');
        }
        else {
            $('.single-fixed-next-prev-posts').removeClass('show');
        }

    });


    // Footer Canvas Menu
    $('.footer-canvas-menu-btn').on('click', function(e) {
        if( $(this).hasClass('active') ) {
            $(this).removeClass('active');
            $('html').removeClass('footer-canvas-menu-active');
        }
        else {
            $(this).addClass('active');
            $('html').addClass('footer-canvas-menu-active');
        }

    });


    // Dark Mode (Fix page cache plugins)
    if ( navigator.cookieEnabled && $('.dark-mode-switcher').length ) {
        let cookies = document.cookie;
        if( cookies.search('kalisaDarkMode=enabled') != -1 ) {
            $('body').addClass("noTransition").addClass('dark-mode');
            setTimeout(function() { $('body').removeClass("noTransition"); }, 200);
        }
        else if( cookies.search('kalisaDarkMode=disabled') != -1 ) {
            $('body').addClass("noTransition").removeClass('dark-mode');
            setTimeout(function() { $('body').removeClass("noTransition"); }, 200);
        }

    }
	
	
    // Dark Mode Switcher
    $('.dark-mode-switcher').on('click', function(e) {
        if( $('body').hasClass('dark-mode') ) {

            $('body').addClass("noTransition").removeClass('dark-mode');
            setTimeout(function() { $('body').removeClass("noTransition"); }, 200);

            if (navigator.cookieEnabled) {
                let date = new Date()
                date.setTime(date.getTime() + (-3*24*60*60*1000));
                document.cookie = 'kalisaDarkMode=disabled; path=/; expires=' + date.toUTCString() + ';';
            }

        }
        else {
            $('body').addClass("noTransition").addClass('dark-mode');
            setTimeout(function() { $('body').removeClass("noTransition"); }, 200);

            if (navigator.cookieEnabled) {
                let date = new Date()
                date.setTime(date.getTime() + (30*24*60*60*1000));
                document.cookie = 'kalisaDarkMode=enabled; path=/; expires=' + date.toUTCString() + ';';

            }
        }

    });



    // Privacy Notice
    if( localStorage.getItem("kalisaPrivacy") != "1" ) {
        $('.privacy-notice-wrap').addClass('show');
    }
    else {
        $('.privacy-notice-wrap').addClass('d-none');
    }

    $('#privacy-btn').on('click', function(e) {
        e.preventDefault();
        localStorage.setItem("kalisaPrivacy", "1");
        $('.privacy-notice-wrap').removeClass('show');
    });



    // Comments Area Collapsable
    $('.comments-list-collapse-btn').on('click', function (e) {
        var commentsArea = $('.comments-area');
        var btn = $(this);

        if( commentsArea.hasClass('collapsed') ) {
            commentsArea.slideDown();
            commentsArea.removeClass('collapsed');
            btn.text( btn.data('hide') );
        }
        else {
            commentsArea.slideUp();
            commentsArea.addClass('collapsed');
            btn.text( btn.data('show') );
        }
    });


    // Single Post Share Link Box
    $(".single-share-box-link .share-link-btn").on('click', function(){
        $(".single-share-box-link .share-link-text").select();
        document.execCommand('copy');
        $('.single-share-box-link .copied-popup-text').addClass('show');
        setTimeout(function () {
            $('.single-share-box-link .copied-popup-text').removeClass('show');
        }, 2000);
    });



    // Infinite Scroll Load More
    $(window).on('scroll', function () {

        $( ".rivax-post-load-more.infinite-scroll" ).each(function( index ) {

            if( isScrolledIntoViewport($(this)) ) {
                $(this).trigger("click");
            }

        });

    });


    // Load more posts ajax
    $('.rivax-post-load-more').on('click', function (e) {
        e.preventDefault();
        if($(this).hasClass('hide')) return;

        var loadMoreBtn = $(this);
        var loadMoreLoader = loadMoreBtn.next('.rivax-post-load-more-loader');
        var scope = loadMoreBtn.closest('.rivax-posts-container').find('.rivax-posts-wrapper');

        var widgetId = $(this).data('widget-id');
        var postId = $(this).data('post-id');
        var pageNumber = $(this).data('current-page') + 1;



        var data = {
            action: 'rivax_get_load_more_posts',
            widgetId: widgetId,
            postId: postId,
            pageNumber: pageNumber,
            qVars: (typeof rivaxLoadMoreQVars !== 'undefined')? rivaxLoadMoreQVars : '',
        };
        $.post({
            url: rivax_ajax_object.AjaxUrl,
            data: data,
            dataType: 'json',
            beforeSend: function() {
                loadMoreBtn.addClass('hide');
                loadMoreLoader.addClass('show');
            },
            success: function(response) {
                if(response.data) {
                    var items = $(response.data);

                    scope.append(items);
                    if( scope.hasClass('layout-masonry') ) {
                        scope.masonry( 'appended', items );
                    }
                }


                if(response.no_more) {
                    loadMoreLoader.remove();
                    loadMoreBtn.remove();
                }
                else {
                    loadMoreBtn.data('current-page', pageNumber);
                }
            },
            error: function() {

            },
            complete: function() {
                loadMoreBtn.removeClass('hide');
                loadMoreLoader.removeClass('show');
            }
        });


    });


	// Contact Form
    $('.rivax-contact-form').on('submit', function (e) {
        e.preventDefault();
        var form = $(this);
        var submitBtn = form.find('.submit-btn');
        var msgWrapper = form.parent('.rivax-contact-form-wrapper').find('.msg-wrapper');

        if(submitBtn.hasClass('loading')) {
            return;
        }

        var data = {
            action: 'rivax_submit_contact_form',
            firstName: form.find('#first-name').val(),
            lastName: form.find('#last-name').val(),
            email: form.find('#email').val(),
            subject: form.find('#subject').val(),
            message: form.find('#message').val(),
        };

        $.post({
            url: rivax_ajax_object.AjaxUrl,
            data: data,
            dataType: 'json',
            beforeSend: function() {
                submitBtn.addClass('loading');
            },
            success: function(response) {
                if(response.msg == 'fill') {
                    msgWrapper.removeClass('success').addClass('error');
                    msgWrapper.children('.msg').text( msgWrapper.children('.msg').data('fill') );
                }
                else if(response.msg == 'error') {
                    msgWrapper.removeClass('success').addClass('error');
                    msgWrapper.children('.msg').text( msgWrapper.children('.msg').data('error') );
                }
                else if(response.msg == 'success') {
                    msgWrapper.removeClass('error').addClass('success');
                    msgWrapper.children('.msg').text( msgWrapper.children('.msg').data('success') );
                    form.trigger("reset");
                }

            },
            error: function() {
                msgWrapper.removeClass('success').addClass('error');
                msgWrapper.children('.msg').text( msgWrapper.children('.msg').data('error') );
            },
            complete: function() {
                submitBtn.removeClass('loading');
            }
        });

    });
	
	
	// Social Icon Widget
	$('.rivax-social-icons a[href=""], .rivax-social-icons a[href="#"]').on('click', function(e) {
		e.preventDefault();
	});
	
	


    var rivaxWidgetsHandler = function( $scope, $ ) {

        // Post Masonry Layout
        var masonryPosts = $scope.find('.rivax-posts-wrapper.layout-masonry');
        if ( masonryPosts.length ){
            masonryPosts.masonry({
                itemSelector: '.post-item',
                percentPosition: true,
            });
        }


        // Post Carousel Layout
        var carouselPosts = $scope.find('.rivax-posts-wrapper.layout-carousel .rivax-posts-carousel-wrapper');
        if ( carouselPosts.length ){
            var carouselSettings = carouselPosts.data('settings');
            var carouselContainer = carouselPosts.find('.swiper');
			var carouselSelector = '#' + carouselPosts.attr('id') + ' .swiper';


            if ( 'undefined' === typeof Swiper ) {
                const asyncSwiper = elementorFrontend.utils.swiper;

                new asyncSwiper( carouselContainer, carouselSettings ).then( ( newSwiperInstance ) => {
                    var swiper = newSwiperInstance;
                } );
            } else {
                var swiper = new Swiper(carouselSelector, carouselSettings);
            }

        }



        // Single Post Gallery Hero
        if ( $('.single-hero-gallery-container').length ){

            if( $('.single-hero-inside .single-hero-gallery-container').length ) {
                var gallerySettings = {
                    slidesPerView: 1,
                    slidesPerGroup: 1,
                    centeredSlides: true,
                    //loop: true,
                    autoplay: true,
                    spaceBetween: 30,
                    a11y: {
                        enabled: false,
                    },
                    navigation: {
                        nextEl: ".single-hero-gallery-container .swiper-button-next",
                        prevEl: ".single-hero-gallery-container .swiper-button-prev",
                    }
                };
            }
            else {
                var gallerySettings = {
                    slidesPerView: 1,
                    slidesPerGroup: 1,
                    centeredSlides: true,
                    //loop: true,
                    autoplay: true,
                    spaceBetween: 30,
                    a11y: {
                        enabled: false,
                    },
                    navigation: {
                        nextEl: ".single-hero-gallery-container .swiper-button-next",
                        prevEl: ".single-hero-gallery-container .swiper-button-prev",
                    },
                    breakpoints: {
                        576: {
                            slidesPerView: 2,
                        },
                        992: {
                            slidesPerView: 2,
                        }
                    }
                };
            }

            var carouselContainer = $('.single-hero-gallery-container .swiper');
			var carouselSelector = '.single-hero-gallery-container .swiper';

            if ( 'undefined' === typeof Swiper ) {
                const asyncSwiper = elementorFrontend.utils.swiper;

                new asyncSwiper( carouselContainer, gallerySettings ).then( ( newSwiperInstance ) => {
                    var swiper = newSwiperInstance;
                } );
            } else {
                var swiper = new Swiper(carouselSelector, gallerySettings);
            }

        }


        // News Ticker
        if( $scope.find('.rivax-news-ticker-content-wrapper').length ) {

            var newsTicker = $scope.find('.rivax-news-ticker-content-wrapper');
            var tickerSettings = newsTicker.data('settings');

            if( newsTicker.hasClass('animation-marquee') ) {

                newsTicker.find('.rivax-news-ticker-items').marquee(tickerSettings);

            }
            else {

                var carouselContainer = newsTicker.find('.swiper');
                var carouselSelector = '#' + newsTicker.attr('id') + ' .swiper';

                if ( 'undefined' === typeof Swiper ) {
                    const asyncSwiper = elementorFrontend.utils.swiper;

                    new asyncSwiper( carouselContainer, tickerSettings ).then( ( newSwiperInstance ) => {
                        var swiper = newSwiperInstance;
                    } );
                } else {
                    var swiper = new Swiper(carouselSelector, tickerSettings);
                }

            }
        }



        // Mailchimp
        if( $scope.find('.rivax-mailchimp-wrapper').length ) {

            var elForm = $scope.find('.rivax-mailchimp-form'),
                elMessage = $scope.find('.rivax-mailchimp-response-message');

            elForm.on('submit', function (e) {
                e.preventDefault();
                var data = {
                    action: 'rivax_mailchimp_subscribe',
                    subscriber_info: elForm.serialize(),
                    list_id: elForm.data('list-id'),
                };
                $.ajax({
                    type: 'post',
                    url: rivax_ajax_object.AjaxUrl,
                    data: data,
                    success: function success(response) {
                        elForm.trigger('reset');

                        if (response.status) {
                            elMessage.removeClass('error');
                            elMessage.addClass('success');
                            elMessage.text(response.msg);
                        } else {
                            elMessage.addClass('error');
                            elMessage.removeClass('success');
                            elMessage.text(response.msg);
                        }

                        var hideMsg = setTimeout(function () {
                            elMessage.removeClass('error');
                            elMessage.removeClass('success');
                            clearTimeout(hideMsg);
                        }, 5000);
                    },
                    error: function error() {

                    }
                });
            });

        }



        // Cross Slider
        if ( $scope.find('.cross-slider-container').length ) {
            var slider = $scope.find('.rivax-posts-carousel-wrapper');
            var sliderSettings = slider.data('settings');
            var sliderContainer = slider.find('.swiper');
            var sliderSelector = '#' + slider.attr('id') + ' .swiper';


            if ( 'undefined' === typeof Swiper ) {
                const asyncSwiper = elementorFrontend.utils.swiper;

                new asyncSwiper( sliderContainer, sliderSettings ).then( ( newSwiperInstance ) => {
                    var swiper = newSwiperInstance;
                } );
            } else {
                var swiper = new Swiper(sliderSelector, sliderSettings);
            }

        }


    }



    // Elementor Widgets
    $( window ).on( 'elementor/frontend/init', function () {

        elementorFrontend.hooks.addAction( 'frontend/element_ready/widget', rivaxWidgetsHandler );

    });


})( jQuery );
