<?php

namespace Elementor;

use RivaxStudio\Traits\Rivax_Group_Control_Query;

if ( ! defined( 'ABSPATH' ) ) { exit; } // Exit if accessed directly


class Rivax_News_Ticker_Widget extends Widget_Base {

    use Rivax_Group_Control_Query;

    public function get_name() {
        return 'rivax-news-ticker';
    }

    public function get_title() {
        return esc_html__('News Ticker', 'kalisa');
    }

    public function get_icon() {
        return 'eicon-posts-ticker';
    }

    protected function get_html_wrapper_class() {
        return $this->get_name() . '-widget';
    }

    public function get_categories() {
        return ['rivax-elements'];
    }

	public function get_style_depends() {
		if (\Elementor\Plugin::$instance->editor->is_edit_mode() || \Elementor\Plugin::$instance->preview->is_preview_mode()) {
			return [];
		}
		
		if ( $this->get_settings_for_display( 'animation_type' ) != 'marquee' ) {
			return [ 'swiper', 'e-swiper' ];
		} else {
			return [];
		}
	}

	public function get_script_depends() {
		if (\Elementor\Plugin::$instance->editor->is_edit_mode() || \Elementor\Plugin::$instance->preview->is_preview_mode()) {
			return ['rivax-marquee'];
		}

		if ( $this->get_settings_for_display( 'animation_type' ) == 'marquee' ) {
			return ['rivax-marquee'];
		} else {
			return [];
		}
	}


    protected function register_settings_controls() {

        $this->start_controls_section(
            'section_settings',
            [
                'label' => esc_html__( 'Settings', 'kalisa' ),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'title_settings',
            [
                'label' => esc_html__( 'Title Settings', 'kalisa' ),
                'type' => Controls_Manager::HEADING,
            ]
        );

        $this->add_control('show_title', [
            'label' => esc_html__('Show Title', 'kalisa'),
            'type' => Controls_Manager::SWITCHER,
        ]);

        $this->add_control(
            'title',
            [
                'label'     => esc_html__( 'Title', 'kalisa' ),
                'type'      => Controls_Manager::TEXT,
                'condition' => [
                    'show_title' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'title_position',
            [
                'label'     => esc_html__( 'Position', 'kalisa' ),
                'type'      => Controls_Manager::CHOOSE,
                'options'   => [
                    '0'   => [
                        'title' => esc_html__( 'Start', 'kalisa' ),
                        'icon'  => 'eicon-order-start',
                    ],
                    '3'  => [
                        'title' => esc_html__( 'End', 'kalisa' ),
                        'icon'  => 'eicon-order-end',
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .rivax-news-ticker-title-wrapper' => 'order: {{VALUE}};',
                ],
                'condition' => [
                    'show_title' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'title_icon_type',
            [
                'label'     => esc_html__( 'Icon Type', 'kalisa' ),
                'type'      => Controls_Manager::SELECT,
                'options'   => [
                    'none'     => esc_html__( 'None', 'kalisa' ),
                    'pulse'  => esc_html__( 'Pulse', 'kalisa' ),
                    'icon' => esc_html__( 'Icon', 'kalisa' ),
                ],
                'default'   => 'none',
                'condition' => [
                    'show_title' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'title_icon_position',
            [
                'label'     => esc_html__( 'Icon Position', 'kalisa' ),
                'type'      => Controls_Manager::CHOOSE,
                'options'   => [
                    '0'   => [
                        'title' => esc_html__( 'Start', 'kalisa' ),
                        'icon'  => 'eicon-order-start',
                    ],
                    '3'  => [
                        'title' => esc_html__( 'End', 'kalisa' ),
                        'icon'  => 'eicon-order-end',
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .rivax-news-ticker-title-icon-wrapper' => 'order: {{VALUE}};',
                ],
                'condition' => [
                    'show_title' => 'yes',
                    'title_icon_type!' => 'none',
                ],
            ]
        );

        $this->add_control(
            'title_icon',
            [
                'label' => esc_html__( 'Icon', 'kalisa' ),
                'type' => Controls_Manager::ICONS,
                'condition' => [
                    'show_title' => 'yes',
                    'title_icon_type' => 'icon',
                ],
            ]
        );


        $this->add_control(
            'title_hr',
            [
                'type' => Controls_Manager::DIVIDER,
            ]
        );


        $this->add_control(
            'item_settings',
            [
                'label' => esc_html__( 'Item Settings', 'kalisa' ),
                'type' => Controls_Manager::HEADING,
            ]
        );


        $this->add_control('open_link_new_tab', [
            'label' => esc_html__('Open Link New Tab', 'kalisa'),
            'type' => Controls_Manager::SWITCHER,
        ]);


        $this->add_control('show_item_icon', [
            'label' => esc_html__('Show icon', 'kalisa'),
            'type' => Controls_Manager::SWITCHER,
        ]);

        $this->add_control(
            'item_icon',
            [
                'label' => esc_html__( 'Icon', 'kalisa' ),
                'type' => Controls_Manager::ICONS,
                'condition' => [
                    'show_item_icon' => 'yes',
                ],
            ]
        );

        $this->add_control('show_item_thumbnail', [
            'label' => esc_html__('Show Featured Image', 'kalisa'),
            'type' => Controls_Manager::SWITCHER,
            'condition' => [
                'show_custom_content!' => 'yes',
            ],
        ]);

        $this->add_control('show_item_date', [
            'label' => esc_html__('Show date', 'kalisa'),
            'type' => Controls_Manager::SWITCHER,
            'condition' => [
                'show_custom_content!' => 'yes',
            ],
        ]);

        $this->add_control(
            'date_format',
            [
                'label' => esc_html__( 'Date Format', 'kalisa' ),
                'type' => Controls_Manager::TEXT,
                'default' => 'F j, Y',
                'condition' => [
                    'show_custom_content!' => 'yes',
                    'show_item_date' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'date_format_info',
            [
                'type'      => Controls_Manager::RAW_HTML,
                'raw'       => sprintf(esc_html__('%s Date Format Documentation %s', 'kalisa'), '<a href="https://wordpress.org/support/article/formatting-date-and-time/" target="_blank">', '</a>'),
                'condition' => [
                    'show_custom_content!' => 'yes',
                    'show_item_date' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'item_hr',
            [
                'type' => Controls_Manager::DIVIDER,
            ]
        );


        $this->add_control(
            'animation_settings',
            [
                'label' => esc_html__( 'Animation Settings', 'kalisa' ),
                'type' => Controls_Manager::HEADING,
            ]
        );

        $this->add_control(
            'animation_type',
            [
                'label'     => esc_html__( 'Animation Type', 'kalisa' ),
                'type'      => Controls_Manager::SELECT,
                'options'   => [
                    'marquee'     => esc_html__( 'Marquee', 'kalisa' ),
                    'type'  => esc_html__( 'Type', 'kalisa' ),
                    'fade' => esc_html__( 'Fade', 'kalisa' ),
                    'horizontal' => esc_html__( 'Horizontal Slide', 'kalisa' ),
                    'vertical' => esc_html__( 'Vertical Slide', 'kalisa' ),
                ],
                'default'   => 'marquee',
            ]
        );

        $this->add_control(
            'marquee_direction',
            [
                'label'     => esc_html__( 'Direction', 'kalisa' ),
                'type'      => Controls_Manager::CHOOSE,
                'options'   => [
                    'left'   => [
                        'title' => esc_html__( 'Left', 'kalisa' ),
                        'icon'  => 'eicon-order-start',
                    ],
                    'right'  => [
                        'title' => esc_html__( 'Right', 'kalisa' ),
                        'icon'  => 'eicon-order-end',
                    ],
                ],
                'default'   => 'left',
                'condition' => [
                    'animation_type' => 'marquee',
                ],
            ]
        );

        $this->add_control('marquee_speed',
            [
                'label' => esc_html__('Speed', 'kalisa'),
                'type' => Controls_Manager::NUMBER,
                'min' => 10,
                'max' => 150,
                'step' => 1,
                'default'   => 20,
                'condition' => [
                    'animation_type' => 'marquee',
                ],
            ]);


        $this->add_control('marquee_loop_gap',
            [
                'label' => esc_html__('Loop Gap', 'kalisa'),
                'type' => Controls_Manager::SLIDER,
                'range'     => [
                    'px' => [
                        'min' => 1,
                        'max' => 300,
                    ],
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => 20,
                ],
                'condition' => [
                    'animation_type' => 'marquee',
                ],
            ]);


        $this->add_responsive_control('marquee_items_gap',
            [
                'label' => esc_html__('Items Gap', 'kalisa'),
                'type' => Controls_Manager::SLIDER,
                'range'     => [
                    'px' => [
                        'min' => 0,
                        'max' => 200,
                    ],
                ],
                'default' => [
	                'unit' => 'px',
	                'size' => 20,
                ],
                'selectors' => [
                    '{{WRAPPER}} .rivax-news-ticker-items .js-marquee-wrapper, {{WRAPPER}} .rivax-news-ticker-items .js-marquee' => 'gap: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'animation_type' => 'marquee',
                ],
            ]);

        $this->add_control('marquee_pauseOnHover', [
            'label' => esc_html__('Pause On Hover', 'kalisa'),
            'type' => Controls_Manager::SWITCHER,
            'condition' => [
                'animation_type' => 'marquee',
            ],
        ]);


        $this->add_responsive_control(
            'carousel_vertical_height',
            [
                'label'       => esc_html__( 'Container Height', 'kalisa' ),
                'type'        => Controls_Manager::SLIDER,
                'range'       => [
                    'px' => [
                        'min'  => 20,
                        'max'  => 600,
                        'step' => 5
                    ],
                ],
                'default'     => [
                    'size' => 20,
                ],
                'selectors'   => [
                    '{{WRAPPER}} .swiper' => 'height: {{SIZE}}{{UNIT}};',
                ],
                'condition'   => [
                    'animation_type' => 'vertical',
                ],
            ]
        );

        $this->add_control(
            'carousel_autoplay',
            [
                'label'   => esc_html__( 'Autoplay', 'kalisa' ),
                'type'    => Controls_Manager::SWITCHER,
                'default' => 'yes',
                'condition'   => [
                    'animation_type!' => 'marquee',
                ],

            ]
        );

        $this->add_control(
            'carousel_autoplay_speed',
            [
                'label'     => esc_html__( 'Autoplay Speed', 'kalisa' ),
                'type'      => Controls_Manager::NUMBER,
                'default'   => 5000,
                'min'  => 2000,
                'max'  => 10000,
                'step' => 100,
                'condition' => [
                    'animation_type!' => 'marquee',
                    'carousel_autoplay' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'carousel_pauseonhover',
            [
                'label' => esc_html__( 'Pause on Hover', 'kalisa' ),
                'type'  => Controls_Manager::SWITCHER,
                'condition'   => [
                    'animation_type!' => 'marquee',
                ],
            ]
        );

        $this->add_control(
            'carousel_speed',
            [
                'label'   => esc_html__( 'Animation Speed (ms)', 'kalisa' ),
                'type'    => Controls_Manager::NUMBER,
                'default' => 500,
                'min'  => 100,
                'max'  => 5000,
                'step' => 100,
                'condition'   => [
                    'animation_type!' => ['marquee', 'type'],
                ],
            ]
        );

        $this->add_control(
            'typing_speed',
            [
                'label'   => esc_html__( 'Typing Speed', 'kalisa' ),
                'type'    => Controls_Manager::NUMBER,
                'default' => 1000,
                'min'  => 500,
                'max'  => 10000,
                'step' => 100,
                'selectors'   => [
                    '{{WRAPPER}} .rivax-news-ticker-wrapper' => '--typing-speed: {{SIZE}}ms;',
                ],
                'condition'   => [
                    'animation_type' => 'type',
                ],
            ]
        );


        $this->add_control(
            'side_fading',
            [
                'label'     => esc_html__( 'Side Fading', 'kalisa' ),
                'type'      => Controls_Manager::SELECT,
                'options'   => [
                    'none'     => esc_html__( 'None', 'kalisa' ),
                    'left'     => esc_html__( 'Left', 'kalisa' ),
                    'right'     => esc_html__( 'Right', 'kalisa' ),
                    'both'     => esc_html__( 'Both', 'kalisa' ),
                ],
                'default'   => 'none',
                'separator' => 'before',
            ]
        );


        $this->add_control(
            'arrows_settings',
            [
                'label' => esc_html__( 'Arrows Settings', 'kalisa' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
                'condition'   => [
                    'animation_type!' => 'marquee',
                ],
            ]
        );

        $this->add_control(
            'carousel_arrows',
            [
                'label'     => esc_html__( 'Arrows', 'kalisa' ),
                'type'      => Controls_Manager::SWITCHER,
                'condition'   => [
                    'animation_type!' => 'marquee',
                ],
            ]
        );

        $this->add_control(
            'carousel_arrows_icon',
            [
                'label'     => esc_html__( 'Arrows Icon', 'kalisa' ),
                'type'      => Controls_Manager::SELECT,
                'default'   => 'ri-angle-right-solid',
                'options'   => rivax_carousel_arrows_icons(),
                'condition' => [
                    'animation_type!' => 'marquee',
                    'carousel_arrows!' => '',
                ],
            ]
        );

        $this->add_control(
            'carousel_arrows_layout',
            [
                'label'     => esc_html__( 'Layout', 'kalisa' ),
                'type'      => Controls_Manager::CHOOSE,
                'options'   => [
                    'row'   => [
                        'title' => esc_html__( 'inline', 'kalisa' ),
                        'icon'  => 'eicon-navigation-horizontal',
                    ],
                    'column'  => [
                        'title' => esc_html__( 'Vertical', 'kalisa' ),
                        'icon'  => 'eicon-navigation-vertical',
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .rivax-news-ticker-arrows' => 'flex-direction: {{VALUE}};',
                ],
                'condition' => [
                    'animation_type!' => 'marquee',
                    'carousel_arrows!' => '',
                ],
            ]
        );



        $this->end_controls_section();

    }


    protected function register_custom_content_controls() {

        $this->start_controls_section(
            'section_custom_content',
            [
                'label' => esc_html__( 'Custom Content', 'kalisa' ),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control('show_custom_content', [
            'label' => esc_html__('Show Custom Content', 'kalisa'),
            'type' => Controls_Manager::SWITCHER,
        ]);

        $repeater = new Repeater();

        $repeater->add_control(
            'custom_content_title',
            [
                'label'     => esc_html__( 'Title', 'kalisa' ),
                'type'      => Controls_Manager::TEXT,
                'default' => esc_html__( 'Custom Title' , 'kalisa' ),
                'label_block' => true,
            ]
        );

        $repeater->add_control(
            'custom_content_url',
            [
                'label'     => esc_html__( 'URL', 'kalisa' ),
                'type'      => Controls_Manager::TEXT,
                'default' => '#',
                'label_block' => true,
            ]
        );

        $this->add_control(
            'custom_content_items',
            [
                'label' => esc_html__( 'Custom Content Items', 'kalisa' ),
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    [
                        'custom_content_title' => esc_html__( 'Title #1', 'kalisa' ),
                        'custom_content_url' => '#',
                    ],
                ],
                'title_field' => '{{{ custom_content_title }}}',
                'condition' => [
                    'show_custom_content' => 'yes',
                ],
            ]
        );


        $this->end_controls_section();

    }


    protected function register_style_controls() {

        $this->start_controls_section('section_style_container',
            [
                'label' => esc_html__('Container', 'kalisa'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control('container_bg',
            [
                'label' => esc_html__('Background Color', 'kalisa'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .rivax-news-ticker-wrapper' => '--ticker-wrapper-bg: {{VALUE}};',
                ],
            ]);

        $this->add_control('container_bg_dark_mode',
            [
                'label' => esc_html__('Background Color - Dark Mode', 'kalisa'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    'body.dark-mode {{WRAPPER}} .rivax-news-ticker-wrapper' => '--ticker-wrapper-bg: {{VALUE}};',
                ],
            ]);

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'container_border',
                'selector' => '{{WRAPPER}} .rivax-news-ticker-wrapper',
            ]);

        $this->add_control('container_border_color_dark_mode',
            [
                'label' => esc_html__('Border Color - Dark Mode', 'kalisa'),
                'type' => Controls_Manager::COLOR,
                'condition' => [
                    'container_border_border!' => '',
                ],
                'selectors' => [
                    'body.dark-mode {{WRAPPER}} .rivax-news-ticker-wrapper' => 'border-color: {{VALUE}};',
                ],
            ]);

        $this->add_responsive_control('container_border_radius',
            [
                'label' => esc_html__('Border Radius', 'kalisa'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .rivax-news-ticker-wrapper' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);

        $this->add_group_control(Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'container_box_shadow',
                'selector' => '{{WRAPPER}} .rivax-news-ticker-wrapper',
            ]);


        $this->end_controls_section();



        $this->start_controls_section('section_style_title',
            [
                'label' => esc_html__('Title', 'kalisa'),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'show_title' => 'yes',
                ],
            ]
        );

        $this->add_control('title_bg',
            [
                'label' => esc_html__('Background Color', 'kalisa'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .rivax-news-ticker-title-wrapper' => 'background-color: {{VALUE}};',
                ],
            ]);

        $this->add_control('title_bg_dark_mode',
            [
                'label' => esc_html__('Background Color - Dark Mode', 'kalisa'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    'body.dark-mode {{WRAPPER}} .rivax-news-ticker-title-wrapper' => 'background-color: {{VALUE}};',
                ],
            ]);

        $this->add_control('title_color',
            [
                'label' => esc_html__('Color', 'kalisa'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .rivax-news-ticker-title-text' => 'color: {{VALUE}};',
                ],
            ]);

        $this->add_control('title_color_dark_mode',
            [
                'label' => esc_html__('Color - Dark Mode', 'kalisa'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    'body.dark-mode {{WRAPPER}} .rivax-news-ticker-title-text' => 'color: {{VALUE}};',
                ],
            ]);

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'title_border',
                'selector' => '{{WRAPPER}} .rivax-news-ticker-title-wrapper',
            ]);

        $this->add_control('title_border_color_dark_mode',
            [
                'label' => esc_html__('Border Color - Dark Mode', 'kalisa'),
                'type' => Controls_Manager::COLOR,
                'condition' => [
                    'title_border_border!' => '',
                ],
                'selectors' => [
                    'body.dark-mode {{WRAPPER}} .rivax-news-ticker-title-text' => 'border-color: {{VALUE}};',
                ],
            ]);

        $this->add_responsive_control('title_border_radius',
            [
                'label' => esc_html__('Border Radius', 'kalisa'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .rivax-news-ticker-title-wrapper' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);

        $this->add_responsive_control('title_padding',
            [
                'label' => esc_html__('Padding', 'kalisa'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .rivax-news-ticker-title-wrapper' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);

        $this->add_group_control(Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'title_box_shadow',
                'selector' => '{{WRAPPER}} .rivax-news-ticker-title-wrapper',
            ]);

        $this->add_control(
            'title_text_settings',
            [
                'label' => esc_html__( 'Text Settings', 'kalisa' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $this->add_responsive_control('title_text_margin',
            [
                'label' => esc_html__('Text Margin', 'kalisa'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .rivax-news-ticker-title-text' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_text_typography',
                'label' => esc_html__('Typography', 'kalisa'),
                'selector' => '{{WRAPPER}} .rivax-news-ticker-title-text',
            ]);


        $this->add_control(
            'title_pulse_settings',
            [
                'label' => esc_html__( 'Pulse Settings', 'kalisa' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
                'condition' => [
                    'title_icon_type' => 'pulse',
                ],
            ]
        );

        $this->add_control('title_pulse_color',
            [
                'label' => esc_html__('Color', 'kalisa'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .rivax-news-ticker-title-pulse' => 'color: {{VALUE}};',
                ],
                'condition' => [
                    'title_icon_type' => 'pulse',
                ],
            ]);

        $this->add_control('title_pulse_color_dark_mode',
            [
                'label' => esc_html__('Color - Dark Mode', 'kalisa'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    'body.dark-mode {{WRAPPER}} .rivax-news-ticker-title-pulse' => 'color: {{VALUE}};',
                ],
                'condition' => [
                    'title_icon_type' => 'pulse',
                ],
            ]);

        $this->add_responsive_control('title_pulse_size',
            [
                'label' => esc_html__('Size', 'kalisa'),
                'type' => Controls_Manager::SLIDER,
                'range'     => [
                    'px' => [
                        'min' => 5,
                        'max' => 50,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .rivax-news-ticker-title-pulse' => 'width: {{SIZE}}{{UNIT}}; height: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'title_icon_type' => 'pulse',
                ],
            ]);

        $this->add_control('title_pulse_border_size',
            [
                'label' => esc_html__('Border Size', 'kalisa'),
                'type' => Controls_Manager::SLIDER,
                'range'     => [
                    'px' => [
                        'min' => 1,
                        'max' => 20,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .rivax-news-ticker-title-pulse::after, {{WRAPPER}} .rivax-news-ticker-title-pulse::before' => 'border-width: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'title_icon_type' => 'pulse',
                ],
            ]);



        $this->add_control(
            'title_icon_settings',
            [
                'label' => esc_html__( 'Icon Settings', 'kalisa' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
                'condition' => [
                    'title_icon_type' => 'icon',
                ],
            ]
        );

        $this->add_control('title_icon_color',
            [
                'label' => esc_html__('Color', 'kalisa'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .rivax-news-ticker-title-icon' => 'color: {{VALUE}};',
                ],
                'condition' => [
                    'title_icon_type' => 'icon',
                ],
            ]);

        $this->add_control('title_icon_color_dark_mode',
            [
                'label' => esc_html__('Color - Dark Mode', 'kalisa'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    'body.dark-mode {{WRAPPER}} .rivax-news-ticker-title-icon' => 'color: {{VALUE}};',
                ],
                'condition' => [
                    'title_icon_type' => 'icon',
                ],
            ]);

        $this->add_control('title_icon_bg',
            [
                'label' => esc_html__('Background Color', 'kalisa'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .rivax-news-ticker-title-icon' => 'background: {{VALUE}};',
                ],
                'condition' => [
                    'title_icon_type' => 'icon',
                ],
            ]);

        $this->add_control('title_icon_bg_dark_mode',
            [
                'label' => esc_html__('Background Color - Dark Mode', 'kalisa'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    'body.dark-mode {{WRAPPER}} .rivax-news-ticker-title-icon' => 'background: {{VALUE}};',
                ],
                'condition' => [
                    'title_icon_type' => 'icon',
                ],
            ]);

        $this->add_responsive_control('title_icon_padding',
            [
                'label' => esc_html__('Padding', 'kalisa'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .rivax-news-ticker-title-icon' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition' => [
                    'title_icon_type' => 'icon',
                ],
            ]);


        $this->add_control('title_icon_size',
            [
                'label' => esc_html__('Size', 'kalisa'),
                'type' => Controls_Manager::NUMBER,
                'min' => 5,
                'max' => 50,
                'selectors' => [
                    '{{WRAPPER}} .rivax-news-ticker-title-icon' => 'font-size: {{VALUE}}px;',
                ],
                'condition' => [
                    'title_icon_type' => 'icon',
                ],
            ]);


        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'title_icon_border',
                'selector' => '{{WRAPPER}} .rivax-news-ticker-title-icon',
                'condition' => [
                    'title_icon_type' => 'icon',
                ],
            ]);

        $this->add_control('title_icon_border_color_dark_mode',
            [
                'label' => esc_html__('Border Color - Dark Mode', 'kalisa'),
                'type' => Controls_Manager::COLOR,
                'condition' => [
                    'title_icon_border_border!' => '',
                    'title_icon_type' => 'icon',
                ],
                'selectors' => [
                    'body.dark-mode {{WRAPPER}} .rivax-news-ticker-title-icon' => 'border-color: {{VALUE}};',
                ],
            ]);

        $this->add_responsive_control('title_icon_radius',
            [
                'label' => esc_html__('Border Radius', 'kalisa'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .rivax-news-ticker-title-icon' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition' => [
                    'title_icon_type' => 'icon',
                ],
            ]);

        $this->add_group_control(Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'title_icon_shadow',
                'selector' => '{{WRAPPER}} .rivax-news-ticker-title-icon',
                'condition' => [
                    'title_icon_type' => 'icon',
                ],
            ]);


        $this->end_controls_section();



        $this->start_controls_section('section_style_item',
            [
                'label' => esc_html__('Item', 'kalisa'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control('items_content_margin',
            [
                'label' => esc_html__('Margin', 'kalisa'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .rivax-news-ticker-content' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);

        $this->add_control(
            'item_title_settings',
            [
                'label' => esc_html__( 'Title', 'kalisa' ),
                'type' => Controls_Manager::HEADING,
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'item_title_typography',
                'label' => esc_html__('Typography', 'kalisa'),
                'selector' => '{{WRAPPER}} .item-title',
            ]);


        $this->start_controls_tabs('item_title_tabs');
        # Normal State Tab
        $this->start_controls_tab(
            'item_title_tab_normal',
            [
                'label' => esc_html__('Normal', 'kalisa'),
            ]
        );

        $this->add_control(
            'item_title_color',
            [
                'label' => esc_html__('Color', 'kalisa'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .item-title' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'item_title_color_dark_mode',
            [
                'label' => esc_html__('Color - Dark Mode', 'kalisa'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    'body.dark-mode {{WRAPPER}} .item-title' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->end_controls_tab();

        # Hover State Tab
        $this->start_controls_tab(
            'item_title_tab_hover',
            [
                'label' => esc_html__('Hover', 'kalisa'),
            ]
        );

        $this->add_control(
            'item_title_color_hover',
            [
                'label' => esc_html__('Color', 'kalisa'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .item-title:hover' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'item_title_color_hover_dark_mode',
            [
                'label' => esc_html__('Color - Dark Mode', 'kalisa'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    'body.dark-mode {{WRAPPER}} .item-title:hover' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->end_controls_tabs();



        $this->add_control(
            'item_icon_settings',
            [
                'label' => esc_html__( 'Icon', 'kalisa' ),
                'type' => Controls_Manager::HEADING,
                'condition' => [
                    'show_item_icon' => 'yes',
                ],
            ]
        );

        $this->add_control('item_icon_color',
            [
                'label' => esc_html__('Color', 'kalisa'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .item-icon' => 'color: {{VALUE}};',
                ],
                'condition' => [
                    'show_item_icon' => 'yes',
                ],
            ]);

        $this->add_control('item_icon_color_dark_mode',
            [
                'label' => esc_html__('Color - Dark Mode', 'kalisa'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    'body.dark-mode {{WRAPPER}} .item-icon' => 'color: {{VALUE}};',
                ],
                'condition' => [
                    'show_item_icon' => 'yes',
                ],
            ]);

        $this->add_control('item_icon_bg',
            [
                'label' => esc_html__('Background Color', 'kalisa'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .item-icon' => 'background: {{VALUE}};',
                ],
                'condition' => [
                    'show_item_icon' => 'yes',
                ],
            ]);

        $this->add_control('item_icon_bg_dark_mode',
            [
                'label' => esc_html__('Background Color - Dark Mode', 'kalisa'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    'body.dark-mode {{WRAPPER}} .item-icon' => 'background: {{VALUE}};',
                ],
                'condition' => [
                    'show_item_icon' => 'yes',
                ],
            ]);

        $this->add_responsive_control('item_icon_padding',
            [
                'label' => esc_html__('Padding', 'kalisa'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .item-icon' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition' => [
                    'show_item_icon' => 'yes',
                ],
            ]);


        $this->add_responsive_control('item_icon_margin',
            [
                'label' => esc_html__('Margin', 'kalisa'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .item-icon' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition' => [
                    'show_item_icon' => 'yes',
                ],
            ]);


        $this->add_control('item_icon_size',
            [
                'label' => esc_html__('Size', 'kalisa'),
                'type' => Controls_Manager::NUMBER,
                'min' => 5,
                'max' => 50,
                'selectors' => [
                    '{{WRAPPER}} .item-icon' => 'font-size: {{VALUE}}px;',
                ],
                'condition' => [
                    'show_item_icon' => 'yes',
                ],
            ]);


        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'item_icon_border',
                'selector' => '{{WRAPPER}} .item-icon',
                'condition' => [
                    'show_item_icon' => 'yes',
                ],
            ]);

        $this->add_control('item_icon_border_color_dark_mode',
            [
                'label' => esc_html__('Border Color - Dark Mode', 'kalisa'),
                'type' => Controls_Manager::COLOR,
                'condition' => [
                    'item_icon_border_border!' => '',
                    'show_item_icon' => 'yes',
                ],
                'selectors' => [
                    'body.dark-mode {{WRAPPER}} .item-icon' => 'border-color: {{VALUE}};',
                ],
            ]);

        $this->add_responsive_control('item_icon_radius',
            [
                'label' => esc_html__('Border Radius', 'kalisa'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .item-icon' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition' => [
                    'show_item_icon' => 'yes',
                ],
            ]);

        $this->add_group_control(Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'item_icon_shadow',
                'selector' => '{{WRAPPER}} .item-icon',
                'condition' => [
                    'show_item_icon' => 'yes',
                ],
            ]);



        $this->add_control(
            'item_thumbnail_settings',
            [
                'label' => esc_html__( 'Thumbnail', 'kalisa' ),
                'type' => Controls_Manager::HEADING,
                'condition' => [
                    'show_item_thumbnail' => 'yes',
                    'show_custom_content!' => 'yes',
                ],
            ]
        );


        $this->add_responsive_control('item_thumbnail_margin',
            [
                'label' => esc_html__('Margin', 'kalisa'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .item-thumbnail' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition' => [
                    'show_item_thumbnail' => 'yes',
                    'show_custom_content!' => 'yes',
                ],
            ]);


        $this->add_control('item_thumbnail_size',
            [
                'label' => esc_html__('Size', 'kalisa'),
                'type' => Controls_Manager::SLIDER,
                'range'     => [
                    'px' => [
                        'min' => 30,
                        'max' => 120,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .item-thumbnail' => 'width: {{SIZE}}{{UNIT}}; height: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'show_item_thumbnail' => 'yes',
                    'show_custom_content!' => 'yes',
                ],
            ]);


        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'item_thumbnail_border',
                'selector' => '{{WRAPPER}} .item-thumbnail img',
                'condition' => [
                    'show_item_thumbnail' => 'yes',
                    'show_custom_content!' => 'yes',
                ],
            ]);

        $this->add_responsive_control('item_thumbnail_radius',
            [
                'label' => esc_html__('Border Radius', 'kalisa'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .item-thumbnail img' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition' => [
                    'show_item_thumbnail' => 'yes',
                    'show_custom_content!' => 'yes',
                ],
            ]);

        $this->add_group_control(Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'item_thumbnail_shadow',
                'selector' => '{{WRAPPER}} .item-thumbnail img',
                'condition' => [
                    'show_item_thumbnail' => 'yes',
                    'show_custom_content!' => 'yes',
                ],
            ]);



        $this->add_control(
            'item_date_settings',
            [
                'label' => esc_html__( 'Date', 'kalisa' ),
                'type' => Controls_Manager::HEADING,
                'condition' => [
                    'show_custom_content!' => 'yes',
                    'show_item_date' => 'yes',
                ],
            ]
        );

        $this->add_control('item_date_color',
            [
                'label' => esc_html__('Color', 'kalisa'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .item-date' => 'color: {{VALUE}};',
                ],
                'condition' => [
                    'show_custom_content!' => 'yes',
                    'show_item_date' => 'yes',
                ],
            ]);

        $this->add_control('item_date_color_dark_mode',
            [
                'label' => esc_html__('Color - Dark Mode', 'kalisa'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    'body.dark-mode {{WRAPPER}} .item-date' => 'color: {{VALUE}};',
                ],
                'condition' => [
                    'show_custom_content!' => 'yes',
                    'show_item_date' => 'yes',
                ],
            ]);

        $this->add_control('item_date_bg',
            [
                'label' => esc_html__('Background Color', 'kalisa'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .item-date' => 'background: {{VALUE}};',
                ],
                'condition' => [
                    'show_custom_content!' => 'yes',
                    'show_item_date' => 'yes',
                ],
            ]);

        $this->add_control('item_date_bg_dark_mode',
            [
                'label' => esc_html__('Background Color - Dark Mode', 'kalisa'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    'body.dark-mode {{WRAPPER}} .item-date' => 'background: {{VALUE}};',
                ],
                'condition' => [
                    'show_custom_content!' => 'yes',
                    'show_item_date' => 'yes',
                ],
            ]);

        $this->add_responsive_control('item_date_padding',
            [
                'label' => esc_html__('Padding', 'kalisa'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .item-date' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition' => [
                    'show_custom_content!' => 'yes',
                    'show_item_date' => 'yes',
                ],
            ]);


        $this->add_responsive_control('item_date_margin',
            [
                'label' => esc_html__('Margin', 'kalisa'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .item-date' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition' => [
                    'show_custom_content!' => 'yes',
                    'show_item_date' => 'yes',
                ],
            ]);


        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'item_date_border',
                'selector' => '{{WRAPPER}} .item-date',
                'condition' => [
                    'show_custom_content!' => 'yes',
                    'show_item_date' => 'yes',
                ],
            ]);

        $this->add_control('item_date_border_color_dark_mode',
            [
                'label' => esc_html__('Border Color - Dark Mode', 'kalisa'),
                'type' => Controls_Manager::COLOR,
                'condition' => [
                    'item_date_border_border!' => '',
                    'show_custom_content!' => 'yes',
                    'show_item_date' => 'yes',
                ],
                'selectors' => [
                    'body.dark-mode {{WRAPPER}} .item-date' => 'border-color: {{VALUE}};',
                ],
            ]);

        $this->add_responsive_control('item_date_radius',
            [
                'label' => esc_html__('Border Radius', 'kalisa'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .item-date' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition' => [
                    'show_custom_content!' => 'yes',
                    'show_item_date' => 'yes',
                ],
            ]);


        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'item_date_typography',
                'label' => esc_html__('Typography', 'kalisa'),
                'selector' => '{{WRAPPER}} .item-date',
                'condition' => [
                    'show_custom_content!' => 'yes',
                    'show_item_date' => 'yes',
                ],
            ]);

        $this->end_controls_section();



        $this->start_controls_section(
            'section_carousel_navigation_style',
            [
                'label'      => esc_html__( 'Navigation', 'kalisa' ),
                'tab'        => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'animation_type!' => 'marquee',
                    'carousel_arrows!' => '',
                ],
            ]
        );

        $this->add_responsive_control(
            'carousel_arrows_section_padding',
            [
                'label'      => esc_html__( 'Section Padding', 'kalisa' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors'  => [
                    '{{WRAPPER}} .rivax-news-ticker-arrows' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control('carousel_arrows_gap',
            [
                'label' => esc_html__('Arrows Gap', 'kalisa'),
                'type' => Controls_Manager::SLIDER,
                'range'     => [
                    'px' => [
                        'min' => 0,
                        'max' => 50,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .rivax-news-ticker-arrows' => 'gap: {{SIZE}}{{UNIT}};',
                ],
            ]);

        $this->add_responsive_control(
            'carousel_arrows_padding',
            [
                'label'      => esc_html__( 'Padding', 'kalisa' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors'  => [
                    '{{WRAPPER}} .carousel-nav-prev, {{WRAPPER}} .carousel-nav-next' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'carousel_arrows_size',
            [
                'label'     => esc_html__( 'Size', 'kalisa' ),
                'type'      => Controls_Manager::SLIDER,
                'range'     => [
                    'px' => [
                        'min' => 10,
                        'max' => 100,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .rivax-news-ticker-arrows' => 'font-size: {{SIZE}}{{UNIT}};',
                ],
            ]
        );


        $this->start_controls_tabs( 'tabs_carousel_arrows_style' );

        $this->start_controls_tab(
            'tabs_carousel_arrows_normal',
            [
                'label'     => esc_html__( 'Normal', 'kalisa' ),
            ]
        );

        $this->add_control(
            'carousel_arrows_color',
            [
                'label'     => esc_html__( 'Color', 'kalisa' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .carousel-nav-prev, {{WRAPPER}} .carousel-nav-next' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'carousel_arrows_color_dark_mode',
            [
                'label'     => esc_html__( 'Color - Dark Mode', 'kalisa' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    'body.dark-mode {{WRAPPER}} .carousel-nav-prev, body.dark-mode {{WRAPPER}} .carousel-nav-next' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'carousel_arrows_background',
            [
                'label'     => esc_html__( 'Background', 'kalisa' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .carousel-nav-prev, {{WRAPPER}} .carousel-nav-next' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'carousel_arrows_bg_dark_mode',
            [
                'label'     => esc_html__( 'Background - Dark Mode', 'kalisa' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    'body.dark-mode {{WRAPPER}} .carousel-nav-prev, body.dark-mode {{WRAPPER}} .carousel-nav-next' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'      => 'carousel_arrows_border',
                'selector'  => '{{WRAPPER}} .carousel-nav-prev, {{WRAPPER}} .carousel-nav-next',
            ]
        );

        $this->add_control('carousel_arrows_border_color_dark_mode',
            [
                'label' => esc_html__('Border Color - Dark Mode', 'kalisa'),
                'type' => Controls_Manager::COLOR,
                'condition' => [
                    'carousel_arrows_border_border!' => '',
                ],
                'selectors' => [
                    'body.dark-mode {{WRAPPER}} .carousel-nav-prev, body.dark-mode {{WRAPPER}} .carousel-nav-next' => 'border-color: {{VALUE}};',
                ],
            ]);

        $this->add_responsive_control(
            'carousel_arrows_border_radius',
            [
                'label'      => esc_html__( 'Border Radius', 'kalisa' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%' ],
                'selectors'  => [
                    '{{WRAPPER}} .carousel-nav-prev, {{WRAPPER}} .carousel-nav-next' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );


        $this->end_controls_tab();

        $this->start_controls_tab(
            'tabs_carousel_arrows_hover',
            [
                'label'     => esc_html__( 'Hover', 'kalisa' ),
            ]
        );

        $this->add_control(
            'carousel_arrows_hover_color',
            [
                'label'     => esc_html__( 'Color', 'kalisa' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .carousel-nav-prev:hover, {{WRAPPER}} .carousel-nav-next:hover' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'carousel_arrows_hover_color_dark_mode',
            [
                'label'     => esc_html__( 'Color - Dark Mode', 'kalisa' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    'body.dark-mode {{WRAPPER}} .carousel-nav-prev:hover, body.dark-mode {{WRAPPER}} .carousel-nav-next:hover' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'carousel_arrows_hover_background',
            [
                'label'     => esc_html__( 'Background', 'kalisa' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .carousel-nav-prev:hover, {{WRAPPER}} .carousel-nav-next:hover' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'carousel_arrows_hover_bg_dark_mode',
            [
                'label'     => esc_html__( 'Background - Dark Mode', 'kalisa' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    'body.dark-mode {{WRAPPER}} .carousel-nav-prev:hover, body.dark-mode {{WRAPPER}} .carousel-nav-next:hover' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'carousel_arrows_hover_border_color',
            [
                'label'     => esc_html__( 'Border Color', 'kalisa' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .carousel-nav-prev:hover, {{WRAPPER}} .carousel-nav-next:hover' => 'border-color: {{VALUE}};',
                ],
                'condition' => [
                    'carousel_arrows_border_border!' => '',
                ],
            ]
        );

        $this->add_control(
            'carousel_arrows_hover_border_color_dark_mode',
            [
                'label'     => esc_html__( 'Border Color - Dark Mode', 'kalisa' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    'body.dark-mode {{WRAPPER}} .carousel-nav-prev:hover, body.dark-mode {{WRAPPER}} .carousel-nav-next:hover' => 'border-color: {{VALUE}};',
                ],
                'condition' => [
                    'carousel_arrows_border_border!' => '',
                ],
            ]
        );

        $this->add_responsive_control(
            'carousel_arrows_hover_border_radius',
            [
                'label'      => esc_html__( 'Border Radius', 'kalisa' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%' ],
                'selectors'  => [
                    '{{WRAPPER}} .carousel-nav-prev:hover, {{WRAPPER}} .carousel-nav-next:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_tab();
        $this->end_controls_tabs();


        $this->end_controls_section();


    }



    protected function register_controls() {

        $this->register_settings_controls();
        $this->register_query_builder_controls();
        $this->register_custom_content_controls();

        $this->register_style_controls();
    }


    protected function render()
    {
        $settings = $this->get_settings_for_display();

        $widget_path_name = str_replace('rivax-', '', $this->get_name() );
        include RIVAX_THEME_DIR . '/elementor/templates/' . $widget_path_name . '/' . $widget_path_name . '.php';
    }

}